@@ -1,7 +1,7 @@
 from django.template.loader import get_template
 
 
-class IconDriver(object):
+class IconDriver:
     context = {}
     _registry = {}
 
@@ -112,18 +112,16 @@ class FontAwesomeLayersDriver(IconDriver):
     name = 'fontawesome-layers'
     template_name = 'appearance/icons/font_awesome_layers.html'
 
-    def __init__(self, data, shadow_class=None):
+    def __init__(self, data):
         self.data = data
-        self.shadow_class = shadow_class
 
     def get_context(self):
         return {
             'data': self.data,
-            'shadow_class': self.shadow_class,
         }
 
 
-class Icon(object):
+class Icon:
     def __init__(self, driver_name, **kwargs):
         self.kwargs = kwargs
         self.driver = IconDriver.get(name=driver_name)(**kwargs)
