@@ -7,16 +7,19 @@ from mptt.fields import TreeForeignKey
 from mptt.models import MPTTModel
 
 from mayan.apps.acls.models import AccessControlList
-from mayan.apps.documents.models import Document
+from mayan.apps.databases.model_mixins import ExtraDataModelMixin
+from mayan.apps.documents.models.document_models import Document
 from mayan.apps.documents.permissions import permission_document_view
+from mayan.apps.events.classes import EventManagerMethodAfter, EventManagerSave
+from mayan.apps.events.decorators import method_event
 
 from .events import (
-    event_cabinet_created, event_cabinet_edited, event_cabinet_add_document,
-    event_cabinet_remove_document
+    event_cabinet_created, event_cabinet_edited, event_cabinet_document_added,
+    event_cabinet_document_removed
 )
 
 
-class Cabinet(MPTTModel):
+class Cabinet(ExtraDataModelMixin, MPTTModel):
     """
     Model to store a hierarchical tree of document containers. Each container
     can store an unlimited number of documents using an M2M field. Only
@@ -36,8 +39,10 @@ class Cabinet(MPTTModel):
         verbose_name=_('Documents')
     )
 
+    class MPTTMeta:
+        order_insertion_by = ('label',)
+
     class Meta:
-        ordering = ('parent__label', 'label')
         # unique_together doesn't work if there is a FK
         # https://code.djangoproject.com/ticket/1751
         unique_together = ('parent', 'label')
@@ -47,27 +52,23 @@ class Cabinet(MPTTModel):
     def __str__(self):
         return self.get_full_path()
 
-    def document_add(self, document, _user=None):
-        """
-        Add a document to a container. This can be done without using this
-        method but this method provides the event commit already coded.
-        """
-        with transaction.atomic():
-            self.documents.add(document)
-            event_cabinet_add_document.commit(
-                action_object=self, actor=_user, target=document
-            )
+    @method_event(
+        action_object='self',
+        event=event_cabinet_document_added,
+        event_manager_class=EventManagerMethodAfter,
+    )
+    def document_add(self, document):
+        self._event_target = document
+        self.documents.add(document)
 
-    def document_remove(self, document, _user=None):
-        """
-        Remove a document from a cabinet. This method provides the
-        corresponding event commit.
-        """
-        with transaction.atomic():
-            self.documents.remove(document)
-            event_cabinet_remove_document.commit(
-                action_object=self, actor=_user, target=document
-            )
+    @method_event(
+        action_object='self',
+        event=event_cabinet_document_removed,
+        event_manager_class=EventManagerMethodAfter,
+    )
+    def document_remove(self, document):
+        self._event_target = document
+        self.documents.remove(document)
 
     def get_absolute_url(self):
         return reverse(
@@ -81,17 +82,24 @@ class Cabinet(MPTTModel):
         Return numeric count of the total documents in a cabinet. The count
         is filtered by access.
         """
-        return self.get_documents_queryset(user=user).count()
+        return self.get_documents_queryset(
+            permission=permission_document_view, user=user
+        ).count()
 
-    def get_documents_queryset(self, user):
+    def get_documents_queryset(self, permission=None, user=None):
         """
         Provide a queryset of the documents in a cabinet. The queryset is
         filtered by access.
         """
-        return AccessControlList.objects.restrict_queryset(
-            permission=permission_document_view, queryset=self.documents,
-            user=user
-        )
+        queryset = self.documents.all()
+
+        if permission and user:
+            queryset = AccessControlList.objects.restrict_queryset(
+                permission=permission_document_view, queryset=queryset,
+                user=user
+            )
+
+        return Document.valid.filter(pk__in=queryset.values('pk'))
 
     def get_full_path(self):
         """
@@ -108,20 +116,19 @@ class Cabinet(MPTTModel):
     )
     get_full_path.short_description = _('Full path')
 
+    @method_event(
+        event_manager_class=EventManagerSave,
+        created={
+            'event': event_cabinet_created,
+            'target': 'self',
+        },
+        edited={
+            'event': event_cabinet_edited,
+            'target': 'self',
+        }
+    )
     def save(self, *args, **kwargs):
-        _user = kwargs.pop('_user', None)
-
-        with transaction.atomic():
-            is_new = not self.pk
-            super(Cabinet, self).save(*args, **kwargs)
-            if is_new:
-                event_cabinet_created.commit(
-                    actor=_user, target=self
-                )
-            else:
-                event_cabinet_edited.commit(
-                    actor=_user, target=self
-                )
+        return super().save(*args, **kwargs)
 
     def validate_unique(self, exclude=None):
         """
