@@ -1,6 +1,6 @@
 from django.core.exceptions import ValidationError
 
-from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.documents.tests.mixins.document_mixins import DocumentTestMixin
 from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..models import Cabinet
@@ -54,7 +54,8 @@ class CabinetDocumentTestCase(
     CabinetTestMixin, DocumentTestMixin, BaseTestCase
 ):
     def setUp(self):
-        super(CabinetDocumentTestCase, self).setUp()
+        super().setUp()
+        self._create_test_document_stub()
         self._create_test_cabinet()
 
     def test_addition_of_documents(self):
