@@ -1,15 +1,14 @@
 from django.utils.encoding import force_text
 
-from mayan.apps.documents.models import DocumentVersion
+from mayan.apps.documents.models import DocumentFile
 from mayan.apps.documents.permissions import (
-    permission_document_new_version, permission_document_version_view,
+    permission_document_file_new, permission_document_file_view,
     permission_document_view
 )
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
 
 from ..exceptions import DocumentAlreadyCheckedOut, DocumentNotCheckedOut
 from ..literals import STATE_CHECKED_OUT, STATE_LABELS
-from ..models import DocumentCheckout
 from ..permissions import (
     permission_document_check_in, permission_document_check_in_override,
     permission_document_check_out, permission_document_check_out_detail_view
@@ -26,9 +25,7 @@ class DocumentCheckoutViewTestCase(
         self._check_out_test_document()
 
         response = self._request_test_document_check_in_get_view()
-        self.assertNotContains(
-            response=response, text=self.test_document.label, status_code=404
-        )
+        self.assertEqual(response.status_code, 404)
 
         self.assertTrue(self.test_document.is_checked_out())
 
@@ -46,6 +43,20 @@ class DocumentCheckoutViewTestCase(
 
         self.assertTrue(self.test_document.is_checked_out())
 
+    def test_trashed_document_check_in_get_view_with_access(self):
+        self._check_out_test_document()
+
+        self.grant_access(
+            obj=self.test_document, permission=permission_document_check_in
+        )
+
+        self.test_document.delete()
+
+        response = self._request_test_document_check_in_get_view()
+        self.assertEqual(response.status_code, 404)
+
+        self.assertTrue(self.test_document.is_checked_out())
+
     def test_document_check_in_post_view_no_permission(self):
         self._check_out_test_document()
 
@@ -65,12 +76,21 @@ class DocumentCheckoutViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertFalse(self.test_document.is_checked_out())
-        self.assertFalse(
-            DocumentCheckout.objects.is_checked_out(
-                document=self.test_document
-            )
+
+    def test_trashed_document_check_in_post_view_with_access(self):
+        self._check_out_test_document()
+
+        self.grant_access(
+            obj=self.test_document, permission=permission_document_check_in
         )
 
+        self.test_document.delete()
+
+        response = self._request_test_document_check_in_post_view()
+        self.assertEqual(response.status_code, 404)
+
+        self.assertTrue(self.test_document.is_checked_out())
+
     def test_document_multiple_check_in_post_view_no_permission(self):
         # Upload second document
         self._upload_test_document()
@@ -83,16 +103,6 @@ class DocumentCheckoutViewTestCase(
 
         self.assertTrue(self.test_documents[0].is_checked_out())
         self.assertTrue(self.test_documents[1].is_checked_out())
-        self.assertTrue(
-            DocumentCheckout.objects.is_checked_out(
-                document=self.test_documents[0]
-            )
-        )
-        self.assertTrue(
-            DocumentCheckout.objects.is_checked_out(
-                document=self.test_documents[1]
-            )
-        )
 
     def test_document_multiple_check_in_post_view_with_document_0_access(self):
         # Upload second document
@@ -110,16 +120,6 @@ class DocumentCheckoutViewTestCase(
 
         self.assertFalse(self.test_documents[0].is_checked_out())
         self.assertTrue(self.test_documents[1].is_checked_out())
-        self.assertFalse(
-            DocumentCheckout.objects.is_checked_out(
-                document=self.test_documents[0]
-            )
-        )
-        self.assertTrue(
-            DocumentCheckout.objects.is_checked_out(
-                document=self.test_documents[1]
-            )
-        )
 
     def test_document_multiple_check_in_post_view_with_access(self):
         # Upload second document
@@ -140,16 +140,6 @@ class DocumentCheckoutViewTestCase(
 
         self.assertFalse(self.test_documents[0].is_checked_out())
         self.assertFalse(self.test_documents[1].is_checked_out())
-        self.assertFalse(
-            DocumentCheckout.objects.is_checked_out(
-                document=self.test_documents[0]
-            )
-        )
-        self.assertFalse(
-            DocumentCheckout.objects.is_checked_out(
-                document=self.test_documents[1]
-            )
-        )
 
     def test_document_check_out_get_view_no_permission(self):
         response = self._request_test_document_check_out_get_view()
@@ -167,6 +157,18 @@ class DocumentCheckoutViewTestCase(
 
         self.assertFalse(self.test_document.is_checked_out())
 
+    def test_trashed_document_check_out_get_view_with_access(self):
+        self.grant_access(
+            obj=self.test_document, permission=permission_document_check_out
+        )
+
+        self.test_document.delete()
+
+        response = self._request_test_document_check_out_get_view()
+        self.assertEqual(response.status_code, 404)
+
+        self.assertFalse(self.test_document.is_checked_out())
+
     def test_document_check_out_post_view_no_permission(self):
         response = self._request_test_document_check_out_post_view()
         self.assertEqual(response.status_code, 404)
@@ -187,6 +189,22 @@ class DocumentCheckoutViewTestCase(
 
         self.assertTrue(self.test_document.is_checked_out())
 
+    def test_trashed_document_check_out_post_view_with_access(self):
+        self.grant_access(
+            obj=self.test_document, permission=permission_document_check_out
+        )
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_check_out_detail_view
+        )
+
+        self.test_document.delete()
+
+        response = self._request_test_document_check_out_post_view()
+        self.assertEqual(response.status_code, 404)
+
+        self.assertFalse(self.test_document.is_checked_out())
+
     def test_document_multiple_check_out_post_view_no_permission(self):
         # Upload second document
         self._upload_test_document()
@@ -205,16 +223,6 @@ class DocumentCheckoutViewTestCase(
 
         self.assertFalse(self.test_documents[0].is_checked_out())
         self.assertFalse(self.test_documents[1].is_checked_out())
-        self.assertFalse(
-            DocumentCheckout.objects.is_checked_out(
-                document=self.test_documents[0]
-            )
-        )
-        self.assertFalse(
-            DocumentCheckout.objects.is_checked_out(
-                document=self.test_documents[1]
-            )
-        )
 
     def test_document_multiple_check_out_post_view_with_document_access(self):
         # Upload second document
@@ -237,16 +245,6 @@ class DocumentCheckoutViewTestCase(
 
         self.assertTrue(self.test_documents[0].is_checked_out())
         self.assertFalse(self.test_documents[1].is_checked_out())
-        self.assertTrue(
-            DocumentCheckout.objects.is_checked_out(
-                document=self.test_documents[0]
-            )
-        )
-        self.assertFalse(
-            DocumentCheckout.objects.is_checked_out(
-                document=self.test_documents[1]
-            )
-        )
 
     def test_document_multiple_check_out_post_view_with_access(self):
         # Upload second document
@@ -272,16 +270,6 @@ class DocumentCheckoutViewTestCase(
 
         self.assertTrue(self.test_documents[0].is_checked_out())
         self.assertTrue(self.test_documents[1].is_checked_out())
-        self.assertTrue(
-            DocumentCheckout.objects.is_checked_out(
-                document=self.test_documents[0]
-            )
-        )
-        self.assertTrue(
-            DocumentCheckout.objects.is_checked_out(
-                document=self.test_documents[1]
-            )
-        )
 
     def test_document_check_out_detail_view_no_permission(self):
         self._check_out_test_document()
@@ -305,6 +293,19 @@ class DocumentCheckoutViewTestCase(
             response, text=STATE_LABELS[STATE_CHECKED_OUT], status_code=200
         )
 
+    def test_trashed_document_check_out_detail_view_with_access(self):
+        self._check_out_test_document()
+
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_check_out_detail_view
+        )
+
+        self.test_document.delete()
+
+        response = self._request_test_document_check_out_detail_view()
+        self.assertEqual(response.status_code, 404)
+
     def test_document_check_out_list_view_no_permission(self):
         self._check_out_test_document()
 
@@ -335,6 +336,25 @@ class DocumentCheckoutViewTestCase(
             response=response, text=self.test_document.label, status_code=200
         )
 
+    def test_trashed_document_check_out_list_view_with_access(self):
+        self._check_out_test_document()
+
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_check_out_detail_view
+        )
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_view
+        )
+
+        self.test_document.delete()
+
+        response = self._request_test_document_check_out_list_view()
+        self.assertNotContains(
+            response=response, text=self.test_document.label, status_code=200
+        )
+
     def test_document_check_in_forcefull_view_no_permission(self):
         # Gitlab issue #237
         # Forcefully checking in a document by a user without adequate
@@ -368,7 +388,25 @@ class DocumentCheckoutViewTestCase(
 
         self.assertFalse(self.test_document.is_checked_out())
 
-    def test_check_in_of_non_checked_out_document(self):
+    def test_trashed_document_check_in_forcefull_view_with_access(self):
+        self._create_test_user()
+        # Check out document as test_user
+        self._check_out_test_document(user=self.test_user)
+
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_check_in_override
+        )
+
+        self.test_document.delete()
+
+        # Check in document as test_case_user
+        response = self._request_test_document_check_in_post_view()
+        self.assertEqual(response.status_code, 404)
+
+        self.assertTrue(self.test_document.is_checked_out())
+
+    def test_check_in_of_non_checked_out_document_view(self):
         self.grant_access(
             obj=self.test_document, permission=permission_document_check_in
         )
@@ -376,10 +414,20 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_check_in_post_view(follow=True)
         self.assertContains(
             response=response, status_code=200,
-            text=force_text(DocumentNotCheckedOut())
+            text=force_text(s=DocumentNotCheckedOut())
         )
 
-    def test_check_out_of_checked_out_document(self):
+    def test_check_in_of_non_checked_out_trashed_document_view(self):
+        self.grant_access(
+            obj=self.test_document, permission=permission_document_check_in
+        )
+
+        self.test_document.delete()
+
+        response = self._request_test_document_check_in_post_view(follow=True)
+        self.assertEqual(response.status_code, 404)
+
+    def test_check_out_of_checked_out_document_view(self):
         self._create_test_user()
         self._check_out_test_document(user=self.test_user)
         self.grant_access(
@@ -393,35 +441,75 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_check_out_post_view(follow=True)
         self.assertContains(
             response=response, status_code=200,
-            text=force_text(DocumentAlreadyCheckedOut())
+            text=force_text(s=DocumentAlreadyCheckedOut())
         )
 
+    def test_check_out_of_checked_out_trashed_document(self):
+        self._create_test_user()
+        self._check_out_test_document(user=self.test_user)
+        self.grant_access(
+            obj=self.test_document, permission=permission_document_check_out
+        )
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_check_out_detail_view
+        )
 
-class NewVersionBlockViewTestCase(
+        self.test_document.delete()
+
+        response = self._request_test_document_check_out_post_view(follow=True)
+        self.assertEqual(response.status_code, 404)
+
+
+class DocumentCheckoutOptionsViewTestCase(
     DocumentCheckoutTestMixin, DocumentCheckoutViewTestMixin,
     GenericDocumentViewTestCase
 ):
-    def test_document_check_out_block_new_version(self):
-        self._check_out_test_document()
-        version_count = DocumentVersion.objects.count()
+    def test_document_check_out_block_new_file_view(self):
+        self._create_test_user()
+        self._check_out_test_document(user=self.test_user)
+        file_count = DocumentFile.objects.count()
 
         self.grant_access(
             obj=self.test_document,
-            permission=permission_document_new_version
+            permission=permission_document_file_new
         )
         self.grant_access(
             obj=self.test_document,
-            permission=permission_document_version_view
+            permission=permission_document_file_view
         )
-
         response = self.post(
-            viewname='sources:document_version_upload', kwargs={
+            viewname='sources:document_file_upload', kwargs={
                 'document_id': self.test_document.pk
             }, follow=True
         )
         self.assertContains(
             response=response, status_code=200,
-            text='Unable to upload new versions'
+            text='Unable to upload new files'
         )
 
-        self.assertEqual(DocumentVersion.objects.count(), version_count)
+        self.assertEqual(DocumentFile.objects.count(), file_count)
+
+    def test_trashed_document_check_out_block_new_version(self):
+        self._check_out_test_document()
+        file_count = DocumentFile.objects.count()
+
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_file_new
+        )
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_file_view
+        )
+
+        self.test_document.delete()
+
+        response = self.post(
+            viewname='sources:document_file_upload', kwargs={
+                'document_id': self.test_document.pk
+            }, follow=True
+        )
+        self.assertEqual(response.status_code, 404)
+
+        self.assertEqual(DocumentFile.objects.count(), file_count)
