@@ -1,7 +1,7 @@
 from django.core import management
 from django.core.management.base import CommandError
 
-from ...signals import perform_upgrade, post_upgrade, pre_upgrade
+from ...signals import signal_perform_upgrade, signal_post_upgrade, signal_pre_upgrade
 
 
 class Command(management.BaseCommand):
@@ -15,10 +15,10 @@ class Command(management.BaseCommand):
 
     def handle(self, *args, **options):
         try:
-            pre_upgrade.send(sender=self)
+            signal_pre_upgrade.send(sender=self)
         except Exception as exception:
             raise CommandError(
-                'Error during pre_upgrade signal: %s, %s' % (
+                'Error during signal_pre_upgrade signal: %s, %s' % (
                     exception, type(exception)
                 )
             )
@@ -32,19 +32,19 @@ class Command(management.BaseCommand):
             )
 
         try:
-            perform_upgrade.send(sender=self)
+            signal_perform_upgrade.send(sender=self)
         except Exception as exception:
             raise CommandError(
-                'Error during perform_upgrade signal; %s, %s' % (
+                'Error during signal_perform_upgrade signal; %s, %s' % (
                     exception, type(exception)
                 )
             )
 
         try:
-            post_upgrade.send(sender=self)
+            signal_post_upgrade.send(sender=self)
         except Exception as exception:
             raise CommandError(
-                'Error during post_upgrade signal; %s, %s' % (
+                'Error during signal_post_upgrade signal; %s, %s' % (
                     exception, type(exception)
                 )
             )
