@@ -5,7 +5,7 @@ from mayan.apps.navigation.classes import Menu
 from .icons import icon_menu_about, icon_menu_user
 
 menu_about = Menu(
-    icon_class=icon_menu_about, label=_('System'), name='about'
+    icon=icon_menu_about, label=_('System'), name='about'
 )
 menu_facet = Menu(label=_('Facet'), name='facet')
 menu_list_facet = Menu(label=_('Facet'), name='list facet')
@@ -15,8 +15,9 @@ menu_object = Menu(label=_('Actions'), name='object')
 menu_related = Menu(label=_('Related'), name='related')
 menu_secondary = Menu(label=_('Secondary'), name='secondary')
 menu_setup = Menu(name='setup')
+menu_return = Menu(label=_('Return'), name='return')
 menu_tools = Menu(name='tools')
 menu_topbar = Menu(name='topbar')
 menu_user = Menu(
-    icon_class=icon_menu_user, name='user', label=_('User')
+    icon=icon_menu_user, name='user', label=_('User')
 )
