@@ -1,29 +1,138 @@
+from functools import reduce
 import logging
 import types
 
 from django.conf import settings
 from django.core.exceptions import FieldDoesNotExist
 from django.db.models.constants import LOOKUP_SEP
-from django.urls import resolve as django_resolve
-from django.urls.base import get_script_prefix
-from django.utils.encoding import force_text
-from django.utils.six.moves import reduce as reduce_function
-
-from mayan.apps.common.compat import dict_type, dictionary_type
 
+from .exceptions import ResolverError, ResolverPipelineError
 from .literals import DJANGO_SQLITE_BACKEND
 
 logger = logging.getLogger(name=__name__)
 
 
+class Resolver:
+    exceptions = ()
+
+    def __init__(self, attribute, obj, kwargs, klass):
+        self.attribute = attribute
+        self.obj = obj
+        self.kwargs = kwargs
+        self.klass = klass
+
+    def resolve(self):
+        try:
+            return self._resolve()
+        except self.exceptions:
+            raise ResolverError
+
+    def _resolve(self):
+        raise NotImplementedError
+
+
+class ResolverObjectAttribute(Resolver):
+    exceptions = (TypeError,)
+
+    def _resolve(self):
+        return self.attribute(self.obj, **self.kwargs)
+
+
+class ResolverGetattr(Resolver):
+    exceptions = (AttributeError, TypeError,)
+
+    def _resolve(self):
+        return getattr(self.obj, self.attribute)
+
+
+class ResolverFunction(Resolver):
+    exceptions = (AttributeError, TypeError,)
+
+    def _resolve(self):
+        return getattr(self.obj, self.attribute)(**self.kwargs)
+
+
+class ResolverDictionary(Resolver):
+    exceptions = (TypeError,)
+
+    def _resolve(self):
+        return self.obj[self.attribute]
+
+
+class ResolverList(Resolver):
+    exceptions = (TypeError,)
+
+    def _resolve(self):
+        result = []
+        for item in self.obj:
+            result.append(
+                self.klass.resolve(
+                    attribute=self.attribute, obj=item, kwargs=self.kwargs
+                )
+            )
+
+        return result
+
+
+class ResolverPipelineObjectAttribute:
+    resolver_list = (
+        ResolverDictionary, ResolverList, ResolverFunction,
+        ResolverObjectAttribute, ResolverGetattr
+    )
+
+    @classmethod
+    def resolve(cls, attribute, obj, kwargs=None):
+        if not kwargs:
+            kwargs = {}
+
+        if '.' in attribute:
+            attribute_list = attribute.split('.')
+        else:
+            attribute_list = (attribute,)
+
+        result = obj
+        for attribute in attribute_list:
+            for resolver in cls.resolver_list:
+                try:
+                    result = resolver(
+                        attribute=attribute, obj=result, kwargs=kwargs, klass=cls
+                    ).resolve()
+                except ResolverError:
+                    """Expected, try the next resolver in the list."""
+
+            if result == obj:
+                raise ResolverPipelineError(
+                    'Unable to resolve attribute "{attribute}" of object "{obj}"'.format(
+                        attribute=attribute, obj=obj
+                    )
+                )
+
+        return result
+
+
+class ResolverRelatedManager(Resolver):
+    exceptions = (AttributeError,)
+
+    def _resolve(self):
+        return getattr(self.obj, self.attribute).all()
+
+
+class ResolverPipelineModelAttribute(ResolverPipelineObjectAttribute):
+    resolver_list = (
+        ResolverDictionary, ResolverList, ResolverRelatedManager,
+        ResolverFunction, ResolverObjectAttribute, ResolverGetattr
+    )
+
+    @classmethod
+    def resolve(cls, attribute, obj, kwargs=None):
+        attribute = attribute.replace(LOOKUP_SEP, '.')
+        return super().resolve(attribute=attribute, obj=obj, kwargs=kwargs)
+
+
 def check_for_sqlite():
     return settings.DATABASES['default']['ENGINE'] == DJANGO_SQLITE_BACKEND and settings.DEBUG is False
 
 
-def convert_to_id_list(items):
-    return ','.join(map(force_text, items))
-
-
 def get_related_field(model, related_field_name):
     try:
         local_field_name, remaining_field_path = related_field_name.split(
@@ -73,11 +182,6 @@ def introspect_attribute(attribute_name, obj):
         return attribute_name, obj
 
 
-def resolve(path, urlconf=None):
-    path = '/{}'.format(path.replace(get_script_prefix(), '', 1))
-    return django_resolve(path=path, urlconf=urlconf)
-
-
 def resolve_attribute(attribute, obj, kwargs=None):
     """
     Resolve the attribute of an object. Behaves like the Python REPL but with
@@ -98,7 +202,7 @@ def resolve_attribute(attribute, obj, kwargs=None):
             try:
                 # If there are dots in the attribute name, traverse them
                 # to the final attribute
-                result = reduce_function(getattr, attribute.split('.'), obj)
+                result = reduce(getattr, attribute.split('.'), obj)
                 try:
                     # Try it as a method
                     return result(**kwargs)
@@ -120,11 +224,11 @@ def return_attrib(obj, attrib, arguments=None):
     if isinstance(attrib, types.FunctionType):
         return attrib(obj)
     elif isinstance(
-        obj, dict_type
-    ) or isinstance(obj, dictionary_type):
+        obj, dict
+    ) or isinstance(obj, dict):
         return obj[attrib]
     else:
-        result = reduce_function(getattr, attrib.split('.'), obj)
+        result = reduce(getattr, attrib.split('.'), obj)
         if isinstance(result, types.MethodType):
             if arguments:
                 return result(**arguments)
@@ -140,4 +244,4 @@ def return_related(instance, related_field):
     meant for related models. Support multiple levels of relationship
     using double underscore.
     """
-    return reduce_function(getattr, related_field.split('__'), instance)
+    return reduce(getattr, related_field.split('__'), instance)
