@@ -15,7 +15,7 @@ logger = logging.getLogger(name=__name__)
 
 class BaseTransformationType(type):
     def __str__(self):
-        return force_text(self.label)
+        return force_text(s=self.label)
 
 
 class BaseTransformation(metaclass=BaseTransformationType):
@@ -66,7 +66,7 @@ class BaseTransformation(metaclass=BaseTransformationType):
     def get_transformation_choices(cls, group_by_layer=False, layer=None):
         if layer:
             transformation_list = [
-                (transformation.name, transformation) for transformation in cls._layer_transformations[layer]
+                (transformation.name, transformation) for transformation in cls._layer_transformations.get(layer, ())
             ]
         else:
             transformation_list = cls._registry.items()
@@ -102,8 +102,8 @@ class BaseTransformation(metaclass=BaseTransformationType):
     @classmethod
     def register(cls, layer, transformation):
         cls._registry[transformation.name] = transformation
-        cls._layer_transformations.setdefault(layer, [])
-        cls._layer_transformations[layer].append(transformation)
+        cls._layer_transformations.setdefault(layer, set())
+        cls._layer_transformations[layer].add(transformation)
 
     def __init__(self, **kwargs):
         self.kwargs = {}
@@ -112,14 +112,14 @@ class BaseTransformation(metaclass=BaseTransformationType):
             self.kwargs[argument_name] = kwargs.get(argument_name)
 
     def cache_hash(self):
-        result = hashlib.sha256(force_bytes(self.name))
+        result = hashlib.sha256(force_bytes(s=self.name))
 
         # Sort arguments for guaranteed repeatability
         for key, value in sorted(self.kwargs.items()):
-            result.update(force_bytes(key))
-            result.update(force_bytes(value))
+            result.update(force_bytes(s=key))
+            result.update(force_bytes(s=value))
 
-        return force_bytes(result.hexdigest())
+        return force_bytes(s=result.hexdigest())
 
     def execute_on(self, image):
         self.image = image
@@ -163,33 +163,32 @@ class AssertTransformationMixin:
             logger.error('Asset "%s" not found.', asset_name)
             raise
         else:
-            with asset.open() as file_object:
-                image_asset = Image.open(fp=file_object)
+            image_asset = asset.get_image()
 
-                if image_asset.mode != 'RGBA':
-                    image_asset.putalpha(alpha=255)
+            if image_asset.mode != 'RGBA':
+                image_asset.putalpha(alpha=255)
 
-                image_asset = image_asset.rotate(
-                    angle=360 - rotation, resample=Image.BICUBIC,
-                    expand=True
+            image_asset = image_asset.rotate(
+                angle=360 - rotation, resample=Image.BICUBIC,
+                expand=True
+            )
+
+            if zoom != 100.0:
+                decimal_value = zoom / 100.0
+                image_asset = image_asset.resize(
+                    (
+                        int(image_asset.size[0] * decimal_value),
+                        int(image_asset.size[1] * decimal_value)
+                    ), Image.ANTIALIAS
                 )
 
-                if zoom != 100.0:
-                    decimal_value = zoom / 100.0
-                    image_asset = image_asset.resize(
-                        (
-                            int(image_asset.size[0] * decimal_value),
-                            int(image_asset.size[1] * decimal_value)
-                        ), Image.ANTIALIAS
-                    )
+            paste_mask = image_asset.getchannel(channel='A').point(
+                lambda i: i * transparency / 100.0
+            )
 
-                paste_mask = image_asset.getchannel(channel='A').point(
-                    lambda i: i * transparency / 100.0
-                )
-
-                return {
-                    'image_asset': image_asset, 'paste_mask': paste_mask
-                }
+            return {
+                'image_asset': image_asset, 'paste_mask': paste_mask
+            }
 
 
 class TransformationAssetPaste(AssertTransformationMixin, BaseTransformation):
@@ -249,7 +248,7 @@ class TransformationAssetPastePercent(TransformationAssetPaste):
     name = 'paste_asset_percent'
 
     def execute_on(self, *args, **kwargs):
-        super(TransformationAssetPaste, self).execute_on(*args, **kwargs)
+        super().execute_on(*args, **kwargs)
 
         try:
             left = float(self.left or '0')
@@ -352,7 +351,7 @@ class TransformationCrop(BaseTransformation):
     name = 'crop'
 
     def execute_on(self, *args, **kwargs):
-        super(TransformationCrop, self).execute_on(*args, **kwargs)
+        super().execute_on(*args, **kwargs)
 
         try:
             left = int(self.left or '0')
@@ -430,7 +429,7 @@ class TransformationDrawRectangle(BaseTransformation):
     name = 'draw_rectangle'
 
     def execute_on(self, *args, **kwargs):
-        super(TransformationDrawRectangle, self).execute_on(*args, **kwargs)
+        super().execute_on(*args, **kwargs)
 
         try:
             left = int(self.left or '0')
@@ -532,7 +531,7 @@ class TransformationDrawRectanglePercent(BaseTransformation):
     name = 'draw_rectangle_percent'
 
     def execute_on(self, *args, **kwargs):
-        super(TransformationDrawRectanglePercent, self).execute_on(*args, **kwargs)
+        super().execute_on(*args, **kwargs)
 
         try:
             left = float(self.left or '0')
@@ -629,7 +628,7 @@ class TransformationFlip(BaseTransformation):
     name = 'flip'
 
     def execute_on(self, *args, **kwargs):
-        super(TransformationFlip, self).execute_on(*args, **kwargs)
+        super().execute_on(*args, **kwargs)
 
         return self.image.transpose(Image.FLIP_TOP_BOTTOM)
 
@@ -640,7 +639,7 @@ class TransformationGaussianBlur(BaseTransformation):
     name = 'gaussianblur'
 
     def execute_on(self, *args, **kwargs):
-        super(TransformationGaussianBlur, self).execute_on(*args, **kwargs)
+        super().execute_on(*args, **kwargs)
 
         return self.image.filter(ImageFilter.GaussianBlur(radius=self.radius))
 
@@ -650,7 +649,7 @@ class TransformationLineArt(BaseTransformation):
     name = 'lineart'
 
     def execute_on(self, *args, **kwargs):
-        super(TransformationLineArt, self).execute_on(*args, **kwargs)
+        super().execute_on(*args, **kwargs)
 
         return self.image.convert('L').point(lambda x: 0 if x < 128 else 255, '1')
 
@@ -661,7 +660,7 @@ class TransformationMirror(BaseTransformation):
     name = 'mirror'
 
     def execute_on(self, *args, **kwargs):
-        super(TransformationMirror, self).execute_on(*args, **kwargs)
+        super().execute_on(*args, **kwargs)
 
         return self.image.transpose(Image.FLIP_LEFT_RIGHT)
 
@@ -672,7 +671,7 @@ class TransformationResize(BaseTransformation):
     name = 'resize'
 
     def execute_on(self, *args, **kwargs):
-        super(TransformationResize, self).execute_on(*args, **kwargs)
+        super().execute_on(*args, **kwargs)
 
         width = int(self.width)
         height = int(self.height or 1.0 * width / self.aspect)
@@ -699,7 +698,7 @@ class TransformationRotate(BaseTransformation):
     name = 'rotate'
 
     def execute_on(self, *args, **kwargs):
-        super(TransformationRotate, self).execute_on(*args, **kwargs)
+        super().execute_on(*args, **kwargs)
 
         self.degrees %= 360
 
@@ -725,7 +724,7 @@ class TransformationRotate90(TransformationRotate):
     name = 'rotate90'
 
     def __init__(self, **kwargs):
-        super(TransformationRotate90, self).__init__()
+        super().__init__()
         self.kwargs['degrees'] = 90
 
 
@@ -736,7 +735,7 @@ class TransformationRotate180(TransformationRotate):
     name = 'rotate180'
 
     def __init__(self, **kwargs):
-        super(TransformationRotate180, self).__init__()
+        super().__init__()
         self.kwargs['degrees'] = 180
 
 
@@ -747,7 +746,7 @@ class TransformationRotate270(TransformationRotate):
     name = 'rotate270'
 
     def __init__(self, **kwargs):
-        super(TransformationRotate270, self).__init__()
+        super().__init__()
         self.kwargs['degrees'] = 270
 
 
@@ -757,7 +756,7 @@ class TransformationUnsharpMask(BaseTransformation):
     name = 'unsharpmask'
 
     def execute_on(self, *args, **kwargs):
-        super(TransformationUnsharpMask, self).execute_on(*args, **kwargs)
+        super().execute_on(*args, **kwargs)
 
         return self.image.filter(
             ImageFilter.UnsharpMask(
@@ -773,7 +772,7 @@ class TransformationZoom(BaseTransformation):
     name = 'zoom'
 
     def execute_on(self, *args, **kwargs):
-        super(TransformationZoom, self).execute_on(*args, **kwargs)
+        super().execute_on(*args, **kwargs)
 
         if self.percent == 100:
             return self.image
