@@ -22,11 +22,11 @@ class Parser:
     _registry = {}
 
     @classmethod
-    def parse_document_page(cls, document_page):
-        for parser_class in cls._registry.get(document_page.document_version.mimetype, ()):
+    def parse_document_file_page(cls, document_file_page):
+        for parser_class in cls._registry.get(document_file_page.document_file.mimetype, ()):
             try:
                 parser = parser_class()
-                parser.process_document_page(document_page)
+                parser.process_document_file_page(document_file_page)
             except ParserError:
                 # If parser raises error, try next parser in the list
                 pass
@@ -36,11 +36,11 @@ class Parser:
                 return
 
     @classmethod
-    def parse_document_version(cls, document_version):
-        for parser_class in cls._registry.get(document_version.mimetype, ()):
+    def parse_document_file(cls, document_file):
+        for parser_class in cls._registry.get(document_file.mimetype, ()):
             try:
                 parser = parser_class()
-                parser.process_document_version(document_version)
+                parser.process_document_file(document_file)
             except ParserError:
                 # If parser raises error, try next parser in the list
                 pass
@@ -57,45 +57,45 @@ class Parser:
                     mimetype, []
                 ).append(parser_class)
 
-    def process_document_version(self, document_version):
+    def process_document_file(self, document_file):
         logger.info(
-            'Starting parsing for document version: %s', document_version
+            'Starting parsing for document file: %s', document_file
         )
-        logger.debug('document version: %d', document_version.pk)
+        logger.debug('document file: %d', document_file.pk)
 
-        for document_page in document_version.pages.all():
-            self.process_document_page(document_page=document_page)
+        for document_file_page in document_file.pages.all():
+            self.process_document_file_page(document_file_page=document_file_page)
 
-    def process_document_page(self, document_page):
-        DocumentPageContent = apps.get_model(
-            app_label='document_parsing', model_name='DocumentPageContent'
+    def process_document_file_page(self, document_file_page):
+        DocumentFilePageContent = apps.get_model(
+            app_label='document_parsing', model_name='DocumentFilePageContent'
         )
 
         logger.info(
-            'Processing page: %d of document version: %s',
-            document_page.page_number, document_page.document_version
+            'Processing page: %d of document file: %s',
+            document_file_page.page_number, document_file_page.document_file
         )
 
-        file_object = document_page.document_version.get_intermediate_file()
+        file_object = document_file_page.document_file.get_intermediate_file()
 
         try:
-            document_page_content, created = DocumentPageContent.objects.get_or_create(
-                document_page=document_page
+            document_file_page_content, created = DocumentFilePageContent.objects.get_or_create(
+                document_file_page=document_file_page
             )
-            document_page_content.content = self.execute(
-                file_object=file_object, page_number=document_page.page_number
+            document_file_page_content.content = self.execute(
+                file_object=file_object, page_number=document_file_page.page_number
             )
-            document_page_content.save()
+            document_file_page_content.save()
         except Exception as exception:
             error_message = _('Exception parsing page; %s') % exception
-            logger.error(error_message)
+            logger.error(error_message, exc_info=True)
             raise ParserError(error_message)
         finally:
             file_object.close()
 
         logger.info(
-            'Finished processing page: %d of document version: %s',
-            document_page.page_number, document_page.document_version
+            'Finished processing page: %d of document file: %s',
+            document_file_page.page_number, document_file_page.document_file
         )
 
     def execute(self, file_object, page_number):
@@ -155,9 +155,9 @@ class PopplerParser(Parser):
             return ''
 
         if output[-3:] == b'\x0a\x0a\x0c':
-            return force_text(output[:-3])
+            return force_text(s=output[:-3])
 
-        return force_text(output)
+        return force_text(s=output)
 
 
 Parser.register(
