@@ -8,11 +8,15 @@ from django.utils.translation import ugettext_lazy as _
 
 from model_utils.managers import InheritanceManager
 
+from mayan.apps.databases.model_mixins import ExtraDataModelMixin
 from mayan.apps.django_gpg.exceptions import VerificationError
 from mayan.apps.django_gpg.models import Key
-from mayan.apps.documents.models import DocumentVersion
+from mayan.apps.documents.models import DocumentFile
+from mayan.apps.events.classes import EventManagerSave
+from mayan.apps.events.decorators import method_event
 from mayan.apps.storage.classes import DefinedStorageLazy
 
+from .events import event_detached_signature_uploaded
 from .literals import STORAGE_NAME_DOCUMENT_SIGNATURES_DETACHED_SIGNATURE
 from .managers import DetachedSignatureManager, EmbeddedSignatureManager
 
@@ -20,7 +24,7 @@ logger = logging.getLogger(name=__name__)
 
 
 def upload_to(*args, **kwargs):
-    return force_text(uuid.uuid4())
+    return force_text(s=uuid.uuid4())
 
 
 class SignatureBaseModel(models.Model):
@@ -33,13 +37,15 @@ class SignatureBaseModel(models.Model):
     it will generate a unique signature ID. No two signature IDs are the same,
     even when using the same key.
     """
-    document_version = models.ForeignKey(
+    document_file = models.ForeignKey(
         editable=False, on_delete=models.CASCADE, related_name='signatures',
-        to=DocumentVersion, verbose_name=_('Document version')
+        to=DocumentFile, verbose_name=_('Document file')
     )
     # Basic fields
-    date = models.DateField(
-        blank=True, editable=False, null=True, verbose_name=_('Date signed')
+    date_time = models.DateTimeField(
+        blank=True, editable=False, null=True, verbose_name=_(
+            'Date and time signed'
+        )
     )
     key_id = models.CharField(
         help_text=_('ID of the key that will be used to sign the document.'),
@@ -59,15 +65,15 @@ class SignatureBaseModel(models.Model):
 
     class Meta:
         ordering = ('pk',)
-        verbose_name = _('Document version signature')
-        verbose_name_plural = _('Document version signatures')
+        verbose_name = _('Document file signature')
+        verbose_name_plural = _('Document file signatures')
 
     def __str__(self):
-        return self.signature_id or '{} - {}'.format(self.date, self.key_id)
+        return self.signature_id or '{} - {}'.format(self.date_time, self.key_id)
 
     def get_absolute_url(self):
         return reverse(
-            viewname='signatures:document_version_signature_details',
+            viewname='signatures:document_file_signature_details',
             kwargs={'signature_id': self.pk}
         )
 
@@ -91,42 +97,59 @@ class SignatureBaseModel(models.Model):
     def is_embedded(self):
         return not hasattr(self, 'signature_file')
 
+    @property
+    def key(self):
+        try:
+            return Key.objects.get(
+                fingerprint=self.public_key_fingerprint
+            )
+        except Key.DoesNotExist:
+            return None
 
-class EmbeddedSignature(SignatureBaseModel):
-    objects = EmbeddedSignatureManager()
+    @property
+    def key_algorithm(self):
+        key = self.key
 
-    class Meta:
-        verbose_name = _('Document version embedded signature')
-        verbose_name_plural = _('Document version embedded signatures')
+        if key:
+            return key.algorithm
 
-    def save(self, *args, **kwargs):
-        logger.debug(msg='checking for embedded signature')
+    @property
+    def key_creation_date(self):
+        key = self.key
 
-        if self.pk:
-            raw = True
-        else:
-            raw = False
+        if key:
+            return key.creation_date
 
-        with self.document_version.open(raw=raw) as file_object:
-            try:
-                verify_result = Key.objects.verify_file(
-                    file_object=file_object
-                )
-            except VerificationError as exception:
-                # Not signed
-                logger.debug(
-                    'embedded signature verification error; %s', exception
-                )
-            else:
-                self.date = verify_result.date
-                self.key_id = verify_result.key_id
-                self.signature_id = verify_result.signature_id
-                self.public_key_fingerprint = verify_result.pubkey_fingerprint
+    @property
+    def key_expiration_date(self):
+        key = self.key
 
-                super(EmbeddedSignature, self).save(*args, **kwargs)
+        if key:
+            return key.expiration_date
+
+    @property
+    def key_length(self):
+        key = self.key
+
+        if key:
+            return key.length
+
+    @property
+    def key_type(self):
+        key = self.key
+
+        if key:
+            return key.get_key_type_display()
+
+    @property
+    def key_user_id(self):
+        key = self.key
+
+        if key:
+            return key.user_id
 
 
-class DetachedSignature(SignatureBaseModel):
+class DetachedSignature(ExtraDataModelMixin, SignatureBaseModel):
     signature_file = models.FileField(
         blank=True, help_text=_(
             'Signature file previously generated.'
@@ -138,19 +161,27 @@ class DetachedSignature(SignatureBaseModel):
     objects = DetachedSignatureManager()
 
     class Meta:
-        verbose_name = _('Document version detached signature')
-        verbose_name_plural = _('Document version detached signatures')
+        verbose_name = _('Document file detached signature')
+        verbose_name_plural = _('Document file detached signatures')
 
     def __str__(self):
-        return '{}-{}'.format(self.document_version, _('signature'))
+        return '{}-{}'.format(self.document_file, _('signature'))
 
     def delete(self, *args, **kwargs):
         if self.signature_file.name:
             self.signature_file.storage.delete(name=self.signature_file.name)
-        super(DetachedSignature, self).delete(*args, **kwargs)
+        super().delete(*args, **kwargs)
 
+    @method_event(
+        event_manager_class=EventManagerSave,
+        created={
+            'action_object': 'self',
+            'event': event_detached_signature_uploaded,
+            'target': 'document_file'
+        },
+    )
     def save(self, *args, **kwargs):
-        with self.document_version.open() as file_object:
+        with self.document_file.open() as file_object:
             try:
                 verify_result = Key.objects.verify_file(
                     file_object=file_object, signature_file=self.signature_file
@@ -163,9 +194,46 @@ class DetachedSignature(SignatureBaseModel):
             else:
                 self.signature_file.seek(0)
 
-                self.date = verify_result.date
+                # Invalid signatures do not have a date attribute
+                self.date_time = getattr(verify_result, 'date_time', None)
                 self.key_id = verify_result.key_id
                 self.signature_id = verify_result.signature_id
                 self.public_key_fingerprint = verify_result.pubkey_fingerprint
 
-        return super(DetachedSignature, self).save(*args, **kwargs)
+        return super().save(*args, **kwargs)
+
+
+class EmbeddedSignature(SignatureBaseModel):
+    objects = EmbeddedSignatureManager()
+
+    class Meta:
+        verbose_name = _('Document file embedded signature')
+        verbose_name_plural = _('Document file embedded signatures')
+
+    def save(self, *args, **kwargs):
+        logger.debug(msg='checking for embedded signature')
+
+        if self.pk:
+            raw = True
+        else:
+            raw = False
+
+        with self.document_file.open(raw=raw) as file_object:
+            try:
+                verify_result = Key.objects.verify_file(
+                    file_object=file_object
+                )
+            except VerificationError as exception:
+                # Not signed
+                logger.debug(
+                    'embedded signature verification error; %s', exception
+                )
+            else:
+                self.date_time = verify_result.date_time
+                self.key_id = verify_result.key_id
+                self.signature_id = verify_result.signature_id
+                self.public_key_fingerprint = verify_result.pubkey_fingerprint
+
+                # Return must be under the else: context to ensure that an
+                # embedded signature instance is created only when valid.
+                return super().save(*args, **kwargs)
