@@ -8,14 +8,20 @@ from ..links import (
     link_workflow_runtime_proxy_state_document_list,
     link_workflow_runtime_proxy_state_list,
 )
-from ..permissions import permission_workflow_view
+from ..permissions import permission_workflow_template_view
 
-from .mixins import WorkflowTestMixin
+from .mixins.workflow_template_mixins import WorkflowTemplateTestMixin
 
 
 class WorkflowRuntimeProxyLinkTestCase(
-    WorkflowTestMixin, GenericDocumentViewTestCase
+    WorkflowTemplateTestMixin, GenericDocumentViewTestCase
 ):
+    auto_upload_test_document = False
+
+    def setUp(self):
+        super().setUp()
+        self._create_test_document_stub()
+
     def _resolve_test_link(self, test_object=None):
         self.add_test_view(test_object=test_object)
         context = self.get_test_view()
@@ -24,7 +30,7 @@ class WorkflowRuntimeProxyLinkTestCase(
     def test_workflow_runtime_proxy_document_list_link_no_permission(self):
         self.test_link = link_workflow_runtime_proxy_document_list
 
-        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_template(add_test_document_type=True)
 
         self._resolve_test_link(test_object=self.test_workflow_runtime_proxy)
 
@@ -33,10 +39,10 @@ class WorkflowRuntimeProxyLinkTestCase(
     def test_workflow_runtime_proxy_document_list_link_with_access(self):
         self.test_link = link_workflow_runtime_proxy_document_list
 
-        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_template(add_test_document_type=True)
 
         self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_view
+            obj=self.test_workflow_template, permission=permission_workflow_template_view
         )
 
         self._resolve_test_link(test_object=self.test_workflow_runtime_proxy)
@@ -54,7 +60,7 @@ class WorkflowRuntimeProxyLinkTestCase(
     def test_workflow_runtime_proxy_link_no_permission(self):
         self.test_link = link_workflow_runtime_proxy_list
 
-        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_template(add_test_document_type=True)
 
         self._resolve_test_link()
         self.assertEqual(self.resolved_test_link, None)
@@ -62,10 +68,10 @@ class WorkflowRuntimeProxyLinkTestCase(
     def test_workflow_runtime_proxy_link_with_access(self):
         self.test_link = link_workflow_runtime_proxy_list
 
-        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_template(add_test_document_type=True)
 
         self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_view
+            obj=self.test_workflow_template, permission=permission_workflow_template_view
         )
 
         self._resolve_test_link()
@@ -81,31 +87,31 @@ class WorkflowRuntimeProxyLinkTestCase(
     def test_workflow_runtime_proxy_state_document_list_link_no_permission(self):
         self.test_link = link_workflow_runtime_proxy_state_document_list
 
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_state()
+        self._create_test_workflow_template(add_test_document_type=True)
+        self._create_test_workflow_template_state()
 
-        self._resolve_test_link(test_object=self.test_workflow_state_runtime_proxy)
+        self._resolve_test_link(test_object=self.test_workflow_template_state_runtime_proxy)
 
         self.assertEqual(self.resolved_test_link, None)
 
     def test_workflow_runtime_proxy_state_document_list_link_with_access(self):
         self.test_link = link_workflow_runtime_proxy_state_document_list
 
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_state()
+        self._create_test_workflow_template(add_test_document_type=True)
+        self._create_test_workflow_template_state()
 
         self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_view
+            obj=self.test_workflow_template, permission=permission_workflow_template_view
         )
 
-        self._resolve_test_link(test_object=self.test_workflow_state_runtime_proxy)
+        self._resolve_test_link(test_object=self.test_workflow_template_state_runtime_proxy)
 
         self.assertNotEqual(self.resolved_test_link, None)
         self.assertEqual(
             self.resolved_test_link.url,
             reverse(
                 viewname=self.test_link.view, kwargs={
-                    'workflow_runtime_proxy_state_id': self.test_workflow_state_runtime_proxy.pk
+                    'workflow_runtime_proxy_state_id': self.test_workflow_template_state_runtime_proxy.pk
                 }
             )
         )
@@ -113,7 +119,7 @@ class WorkflowRuntimeProxyLinkTestCase(
     def test_workflow_runtime_proxy_state_list_link_no_permission(self):
         self.test_link = link_workflow_runtime_proxy_state_list
 
-        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_template(add_test_document_type=True)
 
         self._resolve_test_link(test_object=self.test_workflow_runtime_proxy)
         self.assertEqual(self.resolved_test_link, None)
@@ -121,10 +127,10 @@ class WorkflowRuntimeProxyLinkTestCase(
     def test_workflow_runtime_proxy_state_list_link_with_access(self):
         self.test_link = link_workflow_runtime_proxy_state_list
 
-        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_template(add_test_document_type=True)
 
         self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_view
+            obj=self.test_workflow_template, permission=permission_workflow_template_view
         )
 
         self._resolve_test_link(test_object=self.test_workflow_runtime_proxy)
