@@ -7,32 +7,34 @@ from mayan.apps.testing.tests.mixins import TestServerTestCaseMixin
 from mayan.apps.testing.tests.mocks import request_method_factory
 
 from ..literals import WORKFLOW_ACTION_ON_ENTRY
-from ..models import Workflow
-from ..permissions import permission_workflow_edit
+from ..models import Workflow, WorkflowInstance
+from ..permissions import permission_workflow_template_edit
 from ..workflow_actions import (
     DocumentPropertiesEditAction, DocumentWorkflowLaunchAction, HTTPAction
 )
 
 from .literals import (
-    TEST_DOCUMENT_EDIT_WORKFLOW_ACTION_DOTTED_PATH,
-    TEST_DOCUMENT_EDIT_WORKFLOW_ACTION_TEXT_LABEL,
-    TEST_DOCUMENT_EDIT_WORKFLOW_ACTION_TEXT_DESCRIPTION,
-    TEST_DOCUMENT_EDIT_WORKFLOW_ACTION_TEXT_DATA,
-    TEST_DOCUMENT_EDIT_WORKFLOW_ACTION_TEMPLATE_DATA,
+    TEST_DOCUMENT_EDIT_WORKFLOW_TEMPLATE_STATE_ACTION_DOTTED_PATH,
+    TEST_DOCUMENT_EDIT_WORKFLOW_TEMPLATE_STATE_ACTION_TEXT_LABEL,
+    TEST_DOCUMENT_EDIT_WORKFLOW_TEMPLATE_STATE_ACTION_TEXT_DESCRIPTION,
+    TEST_DOCUMENT_EDIT_WORKFLOW_TEMPLATE_STATE_ACTION_TEXT_DATA,
+    TEST_DOCUMENT_EDIT_WORKFLOW_TEMPLATE_STATE_ACTION_TEMPLATE_DATA,
     TEST_HEADERS_AUTHENTICATION_KEY, TEST_HEADERS_AUTHENTICATION_VALUE,
     TEST_HEADERS_KEY, TEST_HEADERS_JSON, TEST_HEADERS_JSON_TEMPLATE,
     TEST_HEADERS_JSON_TEMPLATE_KEY, TEST_HEADERS_VALUE, TEST_PAYLOAD_JSON,
     TEST_PAYLOAD_TEMPLATE_DOCUMENT_LABEL, TEST_SERVER_USERNAME,
     TEST_SERVER_PASSWORD
 )
-from .mixins import (
-    DocumentWorkflowLaunchActionViewTestMixin,
-    WorkflowStateActionViewTestMixin, WorkflowTestMixin
+from .mixins.workflow_template_mixins import WorkflowTemplateTestMixin
+from .mixins.workflow_template_state_mixins import (
+    WorkflowTemplateStateActionLaunchViewTestMixin,
+    WorkflowTemplateStateActionViewTestMixin
 )
 
 
 class HTTPWorkflowActionTestCase(
-    TestServerTestCaseMixin, GenericDocumentViewTestCase, WorkflowTestMixin,
+    TestServerTestCaseMixin, GenericDocumentViewTestCase,
+    WorkflowTemplateTestMixin,
 ):
     auto_upload_test_document = False
     auto_add_test_view = True
@@ -71,7 +73,8 @@ class HTTPWorkflowActionTestCase(
 
     @mock.patch('requests.sessions.Session.get_adapter')
     def test_http_post_action_payload_template(self, mock_object):
-        self._upload_test_document()
+        self._create_test_document_stub()
+
         mock_object.side_effect = request_method_factory(test_case=self)
 
         action = HTTPAction(
@@ -110,7 +113,8 @@ class HTTPWorkflowActionTestCase(
 
     @mock.patch('requests.sessions.Session.get_adapter')
     def test_http_post_action_headers_template(self, mock_object):
-        self._upload_test_document()
+        self._create_test_document_stub()
+
         mock_object.side_effect = request_method_factory(test_case=self)
 
         action = HTTPAction(
@@ -198,15 +202,16 @@ class HTTPWorkflowActionTestCase(
 
 
 class HTTPWorkflowActionViewTestCase(
-    WorkflowTestMixin, WorkflowStateActionViewTestMixin, GenericViewTestCase
+    WorkflowTemplateTestMixin, WorkflowTemplateStateActionViewTestMixin,
+    GenericViewTestCase
 ):
     def setUp(self):
-        super(HTTPWorkflowActionViewTestCase, self).setUp()
-        self._create_test_workflow()
-        self._create_test_workflow_state()
+        super().setUp()
+        self._create_test_workflow_template()
+        self._create_test_workflow_template_state()
 
     def test_http_workflow_state_action_create_post_view_no_permission(self):
-        action_count = self.test_workflow_state.actions.count()
+        action_count = self.test_workflow_template_state.actions.count()
 
         response = self._request_test_workflow_template_state_action_create_post_view(
             class_path='mayan.apps.document_states.workflow_actions.HTTPAction',
@@ -216,16 +221,17 @@ class HTTPWorkflowActionViewTestCase(
         )
         self.assertEqual(response.status_code, 404)
 
-        self.test_workflow_state.refresh_from_db()
+        self.test_workflow_template_state.refresh_from_db()
         self.assertEqual(
-            self.test_workflow_state.actions.count(), action_count
+            self.test_workflow_template_state.actions.count(), action_count
         )
 
     def test_http_workflow_state_action_create_post_view_with_access(self):
         self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_edit
+            obj=self.test_workflow_template,
+            permission=permission_workflow_template_edit
         )
-        action_count = self.test_workflow_state.actions.count()
+        action_count = self.test_workflow_template_state.actions.count()
 
         response = self._request_test_workflow_template_state_action_create_post_view(
             class_path='mayan.apps.document_states.workflow_actions.HTTPAction',
@@ -235,22 +241,22 @@ class HTTPWorkflowActionViewTestCase(
         )
         self.assertEqual(response.status_code, 302)
 
-        self.test_workflow_state.refresh_from_db()
+        self.test_workflow_template_state.refresh_from_db()
         self.assertEqual(
-            self.test_workflow_state.actions.count(), action_count + 1
+            self.test_workflow_template_state.actions.count(), action_count + 1
         )
 
 
 class DocumentPropertiesEditActionTestCase(
-    WorkflowTestMixin, GenericDocumentViewTestCase
+    WorkflowTemplateTestMixin, GenericDocumentViewTestCase
 ):
     auto_upload_test_document = False
 
     def test_document_properties_edit_action_field_literals(self):
-        self._upload_test_document()
+        self._create_test_document_stub()
 
         action = DocumentPropertiesEditAction(
-            form_data=TEST_DOCUMENT_EDIT_WORKFLOW_ACTION_TEXT_DATA
+            form_data=TEST_DOCUMENT_EDIT_WORKFLOW_TEMPLATE_STATE_ACTION_TEXT_DATA
         )
 
         test_values = self._model_instance_to_dictionary(
@@ -267,12 +273,12 @@ class DocumentPropertiesEditActionTestCase(
         )
 
     def test_document_properties_edit_action_field_templates(self):
-        self._upload_test_document()
+        self._create_test_document_stub()
 
         label = self.test_document.label
 
         action = DocumentPropertiesEditAction(
-            form_data=TEST_DOCUMENT_EDIT_WORKFLOW_ACTION_TEMPLATE_DATA
+            form_data=TEST_DOCUMENT_EDIT_WORKFLOW_TEMPLATE_STATE_ACTION_TEMPLATE_DATA
         )
         action.execute(context={'document': self.test_document})
 
@@ -286,44 +292,52 @@ class DocumentPropertiesEditActionTestCase(
         )
 
     def test_document_properties_edit_action_workflow_execute(self):
-        self._create_test_workflow()
-        self._create_test_workflow_states()
-        self._create_test_workflow_transitions()
+        self._create_test_workflow_template()
+        self._create_test_workflow_template_state()
+        self._create_test_workflow_template_state()
+        self._create_test_workflow_template_transition()
+        self._create_test_workflow_template_transition()
 
-        self.test_workflow_states[1].actions.create(
+        self.test_workflow_template_states[1].actions.create(
             action_data=json.dumps(
-                obj=TEST_DOCUMENT_EDIT_WORKFLOW_ACTION_TEXT_DATA
+                obj=TEST_DOCUMENT_EDIT_WORKFLOW_TEMPLATE_STATE_ACTION_TEXT_DATA
             ),
-            action_path=TEST_DOCUMENT_EDIT_WORKFLOW_ACTION_DOTTED_PATH,
+            action_path=TEST_DOCUMENT_EDIT_WORKFLOW_TEMPLATE_STATE_ACTION_DOTTED_PATH,
             label='', when=WORKFLOW_ACTION_ON_ENTRY,
         )
-        self.test_workflow.document_types.add(self.test_document_type)
+        self.test_workflow_template.document_types.add(
+            self.test_document_type
+        )
 
-        self._upload_test_document()
+        self._create_test_document_stub()
 
         test_workflow_instance = self.test_document.workflows.first()
-        test_workflow_instance.do_transition(transition=self.test_workflow_transition)
+        test_workflow_instance.do_transition(
+            transition=self.test_workflow_template_transition
+        )
 
         self.assertEqual(
             self.test_document.label,
-            TEST_DOCUMENT_EDIT_WORKFLOW_ACTION_TEXT_LABEL
+            TEST_DOCUMENT_EDIT_WORKFLOW_TEMPLATE_STATE_ACTION_TEXT_LABEL
         )
         self.assertEqual(
             self.test_document.description,
-            TEST_DOCUMENT_EDIT_WORKFLOW_ACTION_TEXT_DESCRIPTION
+            TEST_DOCUMENT_EDIT_WORKFLOW_TEMPLATE_STATE_ACTION_TEXT_DESCRIPTION
         )
 
 
 class DocumentWorkflowLaunchActionTestCase(
-    WorkflowTestMixin, GenericDocumentViewTestCase
+    WorkflowTemplateTestMixin, GenericDocumentViewTestCase
 ):
     auto_upload_test_document = False
 
     def test_document_workflow_launch_action(self):
-        self._create_test_workflow(add_document_type=True, auto_launch=False)
-        self._create_test_workflow_state()
+        self._create_test_workflow_template(
+            add_test_document_type=True, auto_launch=False
+        )
+        self._create_test_workflow_template_state()
 
-        self._upload_test_document()
+        self._create_test_document_stub()
 
         action = DocumentWorkflowLaunchAction(
             form_data={'workflows': Workflow.objects.all()}
@@ -334,29 +348,69 @@ class DocumentWorkflowLaunchActionTestCase(
         action.execute(context={'document': self.test_document})
 
         self.assertTrue(
-            workflow_count + 1, self.test_document.workflows.count()
+            self.test_document.workflows.count(), workflow_count + 1
         )
 
 
 class DocumentWorkflowLaunchActionViewTestCase(
-    DocumentWorkflowLaunchActionViewTestMixin, WorkflowTestMixin,
-    GenericDocumentViewTestCase
+    WorkflowTemplateStateActionLaunchViewTestMixin,
+    WorkflowTemplateTestMixin, GenericDocumentViewTestCase
 ):
     auto_upload_test_document = False
 
     def test_document_workflow_launch_action_view_with_full_access(self):
-        self._create_test_workflow(add_document_type=True, auto_launch=False)
-        self._create_test_workflow_state()
-
-        self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_edit
+        self._create_test_workflow_template(
+            add_test_document_type=True, auto_launch=False
         )
 
-        action_count = self.test_workflow_state.actions.count()
+        self._create_test_workflow_template(
+            add_test_document_type=True, auto_launch=False
+        )
+        self._create_test_workflow_template_state()
 
-        response = self._request_document_workflow_launch_action_create_view()
+        self.grant_access(
+            obj=self.test_workflow_template,
+            permission=permission_workflow_template_edit
+        )
+
+        action_count = self.test_workflow_template_state.actions.count()
+
+        response = self._request_document_workflow_template_launch_action_create_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(
-            self.test_workflow_state.actions.count(), action_count + 1
+            self.test_workflow_template_state.actions.count(),
+            action_count + 1
+        )
+
+    def test_document_workflow_launch_action_view_and_document_create_with_full_access(self):
+        self._create_test_workflow_template(
+            add_test_document_type=True, auto_launch=False
+        )
+
+        self._create_test_workflow_template(
+            add_test_document_type=True, auto_launch=True
+        )
+        self._create_test_workflow_template_state()
+
+        self.grant_access(
+            obj=self.test_workflow_template,
+            permission=permission_workflow_template_edit
+        )
+
+        action_count = self.test_workflow_template_state.actions.count()
+        workflow_instance_count = WorkflowInstance.objects.count()
+
+        response = self._request_document_workflow_template_launch_action_create_view()
+        self.assertEqual(response.status_code, 302)
+
+        self.assertEqual(
+            self.test_workflow_template_state.actions.count(),
+            action_count + 1
+        )
+
+        self._create_test_document_stub()
+
+        self.assertEqual(
+            WorkflowInstance.objects.count(), workflow_instance_count + 2
         )
