@@ -6,6 +6,11 @@ from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _
 from django.utils.text import format_lazy
 
+__all__ = (
+    'BaseDocumentFilenameGenerator', 'OriginalDocumentFilenameGenerator',
+    'UUIDDocumentFilenameGenerator'
+)
+
 
 class BaseDocumentFilenameGenerator:
     default = None
@@ -17,13 +22,18 @@ class BaseDocumentFilenameGenerator:
 
     @classmethod
     def get_choices(cls):
-        return sorted(
-            [
+        choices = []
+
+        for name, klass in cls._registry.items():
+            choices.append(
                 (
-                    name, format_lazy('{} - {}', klass.label, klass.description)
-                ) for name, klass in cls._registry.items()
-            ]
-        )
+                    name, format_lazy(
+                        '{} - {}', klass.label, klass.description
+                    )
+                )
+            )
+
+        return sorted(choices)
 
     @classmethod
     def get_default(cls):
@@ -58,12 +68,27 @@ class UUIDDocumentFilenameGenerator(BaseDocumentFilenameGenerator):
     name = 'uuid'
     label = _('UUID')
     description = _(
-        'Generate an immutable, random UUID (RFC 4122) for each file.'
+        'Generates an immutable, random UUID (RFC 4122) for each file.'
     )
 
     def upload_to(self, instance, filename):
-        return force_text(uuid.uuid4())
+        return force_text(s=uuid.uuid4())
 
 
-BaseDocumentFilenameGenerator.register(klass=OriginalDocumentFilenameGenerator)
+class UUIDPlusOriginalFilename(BaseDocumentFilenameGenerator):
+    name = 'uuid_plus_original'
+    label = _('UUID plus original')
+    description = _(
+        'Generates an immutable, random UUID (RFC 4122) for each file and '
+        'appends the original filename of the uploaded file.'
+    )
+
+    def upload_to(self, instance, filename):
+        return '{}_{}'.format(uuid.uuid4(), instance.document.label)
+
+
+BaseDocumentFilenameGenerator.register(
+    klass=OriginalDocumentFilenameGenerator
+)
 BaseDocumentFilenameGenerator.register(klass=UUIDDocumentFilenameGenerator)
+BaseDocumentFilenameGenerator.register(klass=UUIDPlusOriginalFilename)
