@@ -18,32 +18,32 @@ from .statistics import (
 )
 
 
-class DashboardWidgetDocumentPagesTotal(DashboardWidgetNumeric):
-    icon_class = icon_dashboard_pages_per_month
+class DashboardWidgetDocumentFilePagesTotal(DashboardWidgetNumeric):
+    icon = icon_dashboard_pages_per_month
     label = _('Total pages')
     link = reverse_lazy(
         viewname='statistics:statistic_detail', kwargs={
             'slug': 'total-document-pages-at-each-month'
         }
     )
-    link_icon_class = icon_statistics
+    link_icon = icon_statistics
 
     def render(self, request):
         AccessControlList = apps.get_model(
             app_label='acls', model_name='AccessControlList'
         )
-        DocumentPage = apps.get_model(
-            app_label='documents', model_name='DocumentPage'
+        DocumentFilePage = apps.get_model(
+            app_label='documents', model_name='DocumentFilePage'
         )
         self.count = AccessControlList.objects.restrict_queryset(
             permission=permission_document_view, user=request.user,
-            queryset=DocumentPage.objects.all()
+            queryset=DocumentFilePage.valid.all()
         ).count()
-        return super(DashboardWidgetDocumentPagesTotal, self).render(request)
+        return super().render(request)
 
 
 class DashboardWidgetDocumentsTotal(DashboardWidgetNumeric):
-    icon_class = icon_dashboard_total_document
+    icon = icon_dashboard_total_document
     label = _('Total documents')
     link = reverse_lazy(viewname='documents:document_list')
 
@@ -56,13 +56,13 @@ class DashboardWidgetDocumentsTotal(DashboardWidgetNumeric):
         )
         self.count = AccessControlList.objects.restrict_queryset(
             permission=permission_document_view, user=request.user,
-            queryset=Document.objects.all()
+            queryset=Document.valid.all()
         ).count()
-        return super(DashboardWidgetDocumentsTotal, self).render(request)
+        return super().render(request)
 
 
 class DashboardWidgetDocumentsInTrash(DashboardWidgetNumeric):
-    icon_class = icon_dashboard_documents_in_trash
+    icon = icon_dashboard_documents_in_trash
     label = _('Documents in trash')
     link = reverse_lazy(viewname='documents:document_list_deleted')
 
@@ -70,18 +70,18 @@ class DashboardWidgetDocumentsInTrash(DashboardWidgetNumeric):
         AccessControlList = apps.get_model(
             app_label='acls', model_name='AccessControlList'
         )
-        DeletedDocument = apps.get_model(
-            app_label='documents', model_name='DeletedDocument'
+        TrashedDocument = apps.get_model(
+            app_label='documents', model_name='TrashedDocument'
         )
         self.count = AccessControlList.objects.restrict_queryset(
             permission=permission_document_view, user=request.user,
-            queryset=DeletedDocument.objects.all()
+            queryset=TrashedDocument.objects.all()
         ).count()
-        return super(DashboardWidgetDocumentsInTrash, self).render(request)
+        return super().render(request)
 
 
 class DashboardWidgetDocumentsTypesTotal(DashboardWidgetNumeric):
-    icon_class = icon_dashboard_document_types
+    icon = icon_dashboard_document_types
     label = _('Document types')
     link = reverse_lazy(viewname='documents:document_type_list')
 
@@ -96,34 +96,34 @@ class DashboardWidgetDocumentsTypesTotal(DashboardWidgetNumeric):
             permission=permission_document_type_view, user=request.user,
             queryset=DocumentType.objects.all()
         ).count()
-        return super(DashboardWidgetDocumentsTypesTotal, self).render(request)
+        return super().render(request)
 
 
 class DashboardWidgetDocumentsNewThisMonth(DashboardWidgetNumeric):
-    icon_class = icon_dashboard_new_documents_this_month
+    icon = icon_dashboard_new_documents_this_month
     label = _('New documents this month')
     link = reverse_lazy(
         viewname='statistics:statistic_detail', kwargs={
             'slug': 'new-documents-per-month'
         }
     )
-    link_icon_class = icon_statistics
+    link_icon = icon_statistics
 
     def render(self, request):
         self.count = new_documents_this_month(user=request.user)
-        return super(DashboardWidgetDocumentsNewThisMonth, self).render(request)
+        return super().render(request)
 
 
 class DashboardWidgetDocumentsPagesNewThisMonth(DashboardWidgetNumeric):
-    icon_class = icon_dashboard_pages_per_month
+    icon = icon_dashboard_pages_per_month
     label = _('New pages this month')
     link = reverse_lazy(
         viewname='statistics:statistic_detail', kwargs={
             'slug': 'new-document-pages-per-month'
         }
     )
-    link_icon_class = icon_statistics
+    link_icon = icon_statistics
 
     def render(self, request):
         self.count = new_document_pages_this_month(user=request.user)
-        return super(DashboardWidgetDocumentsPagesNewThisMonth, self).render(request)
+        return super().render(request)
