@@ -7,9 +7,6 @@ from whoosh.filedb.filestore import FileStorage
 from whoosh.index import EmptyIndexError
 
 from django.conf import settings
-from django.db import models
-
-from colorful.fields import RGBColorField
 
 from mayan.apps.lock_manager.backends.base import LockingBackend
 from mayan.apps.lock_manager.exceptions import LockError
@@ -17,16 +14,7 @@ from mayan.apps.lock_manager.exceptions import LockError
 from ..classes import SearchBackend, SearchField, SearchModel
 from ..settings import setting_results_limit
 
-DJANGO_TO_WHOOSH_FIELD_MAP = {
-    models.AutoField: {
-        'field': whoosh.fields.ID(stored=True), 'transformation': str
-    },
-    models.CharField: {'field': whoosh.fields.TEXT},
-    models.TextField: {'field': whoosh.fields.TEXT},
-    models.UUIDField: {'field': whoosh.fields.TEXT, 'transformation': str},
-    RGBColorField: {'field': whoosh.fields.TEXT},
-}
-INDEX_DIRECTORY_NAME = 'whoosh'
+from .literals import DJANGO_TO_WHOOSH_FIELD_MAP, WHOOSH_INDEX_DIRECTORY_NAME
 logger = logging.getLogger(name=__name__)
 
 
@@ -37,7 +25,7 @@ class WhooshSearchBackend(SearchBackend):
         super().__init__(**kwargs)
         self.index_path = Path(
             self.kwargs.get(
-                'index_path', Path(settings.MEDIA_ROOT, INDEX_DIRECTORY_NAME)
+                'index_path', Path(settings.MEDIA_ROOT, WHOOSH_INDEX_DIRECTORY_NAME)
             )
         )
         self.index_path.mkdir(exist_ok=True)
@@ -98,7 +86,7 @@ class WhooshSearchBackend(SearchBackend):
 
     def deindex_instance(self, instance):
         try:
-            lock = LockingBackend.get_instance().acquire_lock(
+            lock = LockingBackend.get_backend().acquire_lock(
                 name='dynamic_search_whoosh_deindex_instance'
             )
         except LockError:
@@ -168,14 +156,14 @@ class WhooshSearchBackend(SearchBackend):
 
     def index_instance(self, instance, exclude_set=None):
         try:
-            lock = LockingBackend.get_instance().acquire_lock(
+            lock = LockingBackend.get_backend().acquire_lock(
                 name='dynamic_search_whoosh_index_instance'
             )
         except LockError:
             raise
         else:
             try:
-                # Use a shadow method to allow using a single lock for
+                # Use a private method to allow using a single lock for
                 # all recursions.
                 self._index_instance(
                     instance=instance, exclude_set=exclude_set
@@ -187,7 +175,7 @@ class WhooshSearchBackend(SearchBackend):
         if not exclude_set:
             exclude_set = set()
 
-        # Avoid infite recursion
+        # Avoid infinite recursion.
         if instance in exclude_set:
             return
 
@@ -210,8 +198,19 @@ class WhooshSearchBackend(SearchBackend):
                 field_map=self.get_resolved_field_map(search_model=search_model), instance=instance
             )
             writer.delete_by_term('id', str(instance.pk))
-            writer.add_document(**kwargs)
-            writer.commit()
+            try:
+                writer.add_document(**kwargs)
+                writer.commit()
+            except Exception as exception:
+                logger.error(
+                    'Unexpected exception while indexing object id: %s, '
+                    'search model: %s, index data: %s, raw data: %s, '
+                    'field map: %s; %s', search_model.get_full_name(),
+                    instance.pk, kwargs, instance.__dict__,
+                    self.get_resolved_field_map(search_model=search_model),
+                    exception, exc_info=True
+                )
+                raise
 
         for field_class in instance._meta.get_fields():
             # Only to recursive indexing for related models that are
