@@ -1,6 +1,8 @@
 from django import forms
 from django.utils.translation import ugettext_lazy as _
 
+from .settings import setting_match_all_default_value
+
 
 class AdvancedSearchForm(forms.Form):
     _match_all = forms.BooleanField(
@@ -12,8 +14,10 @@ class AdvancedSearchForm(forms.Form):
     )
 
     def __init__(self, *args, **kwargs):
+        kwargs['data'] = kwargs['data'].copy()
+        kwargs['data']['_match_all'] = setting_match_all_default_value.value
         self.search_model = kwargs.pop('search_model')
-        super(AdvancedSearchForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         for name, label in self.search_model.get_fields_simple_list():
             self.fields[name] = forms.CharField(
