@@ -1,5 +1,6 @@
 import logging
 
+from django.conf import settings
 from django.contrib import messages
 from django.template import RequestContext
 from django.urls import reverse
@@ -12,17 +13,18 @@ from mayan.apps.views.generics import (
 from mayan.apps.views.literals import LIST_MODE_CHOICE_ITEM
 
 from .classes import SearchBackend, SearchModel
+from .exceptions import DynamicSearchException
 from .forms import SearchForm, AdvancedSearchForm
 from .icons import icon_search_submit
 from .links import link_search_again
-from .mixins import SearchModelMixin
 from .permissions import permission_search_tools
 from .tasks import task_index_search_model
+from .view_mixins import SearchModelViewMixin
 
 logger = logging.getLogger(name=__name__)
 
 
-class ResultsView(SearchModelMixin, SingleObjectListView):
+class ResultsView(SearchModelViewMixin, SingleObjectListView):
     def get_extra_context(self):
         context = {
             'hide_object': True,
@@ -48,8 +50,6 @@ class ResultsView(SearchModelMixin, SingleObjectListView):
         return context
 
     def get_source_queryset(self):
-        self.search_model = self.get_search_model()
-
         if self.request.GET:
             # Only do search if there is user input, otherwise just render
             # the template with the extra_context
@@ -59,13 +59,20 @@ class ResultsView(SearchModelMixin, SingleObjectListView):
             else:
                 global_and_search = False
 
-            queryset = SearchBackend.get_instance().search(
-                global_and_search=global_and_search,
-                search_model=self.search_model,
-                query_string=self.request.GET, user=self.request.user
-            )
+            try:
+                queryset = SearchBackend.get_instance().search(
+                    global_and_search=global_and_search,
+                    search_model=self.search_model,
+                    query_string=self.request.GET, user=self.request.user
+                )
+            except DynamicSearchException as exception:
+                if settings.DEBUG or settings.TESTING:
+                    raise
 
-            return queryset
+                messages.error(message=exception, request=self.request)
+                return self.search_model.model._meta.default_manager.none()
+            else:
+                return queryset
 
 
 class SearchAgainView(RedirectView):
@@ -112,7 +119,7 @@ class SearchBackendReindexView(ConfirmView):
         )
 
 
-class SearchView(SearchModelMixin, SimpleView):
+class SearchView(SearchModelViewMixin, SimpleView):
     template_name = 'appearance/generic_form.html'
     title = _('Search')
 
@@ -126,7 +133,7 @@ class SearchView(SearchModelMixin, SimpleView):
                 }
             ),
             'search_model': self.search_model,
-            'submit_icon_class': icon_search_submit,
+            'submit_icon': icon_search_submit,
             'submit_label': _('Search'),
             'submit_method': 'GET',
             'title': _('Search for: %s') % self.search_model.label,
