@@ -2,14 +2,12 @@ import logging
 
 from django.contrib import messages
 from django.core.exceptions import PermissionDenied
-from django.db import transaction
 from django.shortcuts import get_object_or_404
 from django.template import RequestContext
 from django.urls import reverse, reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.acls.models import AccessControlList
-from mayan.apps.documents.events import event_document_type_edited
 from mayan.apps.documents.models import Document, DocumentType
 from mayan.apps.documents.permissions import (
     permission_document_type_edit, permission_document_view
@@ -19,7 +17,7 @@ from mayan.apps.views.generics import (
     AddRemoveView, SingleObjectCreateView, SingleObjectDeleteView,
     SingleObjectEditView, SingleObjectListView
 )
-from mayan.apps.views.mixins import ExternalObjectMixin
+from mayan.apps.views.mixins import ExternalObjectViewMixin
 
 from .events import event_smart_link_edited
 from .forms import SmartLinkConditionForm, SmartLinkForm
@@ -34,9 +32,7 @@ from .permissions import (
 logger = logging.getLogger(name=__name__)
 
 
-class DocumentTypeSmartLinksView(AddRemoveView):
-    main_object_method_add = 'smart_link_add'
-    main_object_method_remove = 'smart_link_remove'
+class DocumentTypeSmartLinkAddRemoveView(AddRemoveView):
     main_object_permission = permission_document_type_edit
     main_object_model = DocumentType
     main_object_pk_url_kwarg = 'document_type_id'
@@ -46,30 +42,24 @@ class DocumentTypeSmartLinksView(AddRemoveView):
     list_added_title = _('Smart links enabled')
     related_field = 'smart_links'
 
-    def action_add(self, queryset, _user):
-        with transaction.atomic():
-            event_document_type_edited.commit(
-                actor=_user, target=self.main_object
+    def action_add(self, queryset, _event_actor):
+        for obj in queryset:
+            self.main_object.smart_links.add(obj)
+            event_smart_link_edited.commit(
+                actor=_event_actor or self._event_actor,
+                action_object=self.main_object, target=obj
             )
-            for obj in queryset:
-                self.main_object.smart_links.add(obj)
-                event_smart_link_edited.commit(
-                    actor=_user, action_object=self.main_object, target=obj
-                )
 
-    def action_remove(self, queryset, _user):
-        with transaction.atomic():
-            event_document_type_edited.commit(
-                actor=_user, target=self.main_object
+    def action_remove(self, queryset, _event_actor):
+        for obj in queryset:
+            self.main_object.smart_links.remove(obj)
+            event_smart_link_edited.commit(
+                actor=_event_actor or self._event_actor,
+                action_object=self.main_object, target=obj
             )
-            for obj in queryset:
-                self.main_object.smart_links.remove(obj)
-                event_smart_link_edited.commit(
-                    actor=_user, action_object=self.main_object, target=obj
-                )
 
     def get_actions_extra_kwargs(self):
-        return {'_user': self.request.user}
+        return {'_event_actor': self.request.user}
 
     def get_extra_context(self):
         return {
@@ -80,17 +70,15 @@ class DocumentTypeSmartLinksView(AddRemoveView):
         }
 
 
-class ResolvedSmartLinkView(ExternalObjectMixin, DocumentListView):
-    external_object_class = Document
+class ResolvedSmartLinkView(ExternalObjectViewMixin, DocumentListView):
     external_object_permission = permission_document_view
     external_object_pk_url_kwarg = 'document_id'
+    external_object_queryset = Document.valid
 
     def dispatch(self, request, *args, **kwargs):
         self.smart_link = self.get_smart_link()
 
-        return super(
-            ResolvedSmartLinkView, self
-        ).dispatch(request, *args, **kwargs)
+        return super().dispatch(request, *args, **kwargs)
 
     def get_document_queryset(self):
         try:
@@ -133,7 +121,7 @@ class ResolvedSmartLinkView(ExternalObjectMixin, DocumentListView):
                 'smart_link': self.smart_link.label,
             }
 
-        context = super(ResolvedSmartLinkView, self).get_extra_context()
+        context = super().get_extra_context()
         context.update(
             {
                 'object': self.external_object,
@@ -154,9 +142,9 @@ class ResolvedSmartLinkView(ExternalObjectMixin, DocumentListView):
         )
 
 
-class SmartLinkDocumentTypesView(AddRemoveView):
-    main_object_method_add = 'document_types_add'
-    main_object_method_remove = 'document_types_remove'
+class SmartLinkDocumentTypeAddRemoveView(AddRemoveView):
+    main_object_method_add_name = 'document_types_add'
+    main_object_method_remove_name = 'document_types_remove'
     main_object_permission = permission_smart_link_edit
     main_object_model = SmartLink
     main_object_pk_url_kwarg = 'smart_link_id'
@@ -167,7 +155,7 @@ class SmartLinkDocumentTypesView(AddRemoveView):
     related_field = 'document_types'
 
     def get_actions_extra_kwargs(self):
-        return {'_user': self.request.user}
+        return {'_event_actor': self.request.user}
 
     def get_extra_context(self):
         return {
@@ -204,10 +192,10 @@ class SmartLinkListView(SingleObjectListView):
         }
 
 
-class DocumentSmartLinkListView(ExternalObjectMixin, SmartLinkListView):
-    external_object_class = Document
+class DocumentSmartLinkListView(ExternalObjectViewMixin, SmartLinkListView):
     external_object_permission = permission_document_view
     external_object_pk_url_kwarg = 'document_id'
+    external_object_queryset = Document.valid
 
     def get_extra_context(self):
         return {
@@ -243,8 +231,8 @@ class SmartLinkCreateView(SingleObjectCreateView):
     )
     view_permission = permission_smart_link_create
 
-    def get_save_extra_data(self):
-        return {'_user': self.request.user}
+    def get_instance_extra_data(self):
+        return {'_event_actor': self.request.user}
 
 
 class SmartLinkDeleteView(SingleObjectDeleteView):
@@ -277,11 +265,11 @@ class SmartLinkEditView(SingleObjectEditView):
             'title': _('Edit smart link: %s') % self.object
         }
 
-    def get_save_extra_data(self):
-        return {'_user': self.request.user}
+    def get_instance_extra_data(self):
+        return {'_event_actor': self.request.user}
 
 
-class SmartLinkConditionListView(ExternalObjectMixin, SingleObjectListView):
+class SmartLinkConditionListView(ExternalObjectViewMixin, SingleObjectListView):
     external_object_class = SmartLink
     external_object_permission = permission_smart_link_edit
     external_object_pk_url_kwarg = 'smart_link_id'
@@ -316,7 +304,7 @@ class SmartLinkConditionListView(ExternalObjectMixin, SingleObjectListView):
 
 
 class SmartLinkConditionCreateView(
-    ExternalObjectMixin, SingleObjectCreateView
+    ExternalObjectViewMixin, SingleObjectCreateView
 ):
     external_object_class = SmartLink
     external_object_permission = permission_smart_link_edit
@@ -332,7 +320,10 @@ class SmartLinkConditionCreateView(
         }
 
     def get_instance_extra_data(self):
-        return {'smart_link': self.external_object}
+        return {
+            '_event_actor': self.request.user,
+            'smart_link': self.external_object
+        }
 
     def get_post_action_redirect(self):
         return reverse(
@@ -360,6 +351,9 @@ class SmartLinkConditionDeleteView(SingleObjectDeleteView):
             ) % self.object,
         }
 
+    def get_instance_extra_data(self):
+        return {'_event_actor': self.request.user}
+
     def get_post_action_redirect(self):
         return reverse(
             viewname='linking:smart_link_condition_list', kwargs={
@@ -382,6 +376,9 @@ class SmartLinkConditionEditView(SingleObjectEditView):
             'title': _('Edit smart link condition'),
         }
 
+    def get_instance_extra_data(self):
+        return {'_event_actor': self.request.user}
+
     def get_post_action_redirect(self):
         return reverse(
             viewname='linking:smart_link_condition_list', kwargs={
