@@ -4,7 +4,10 @@ from mayan.celery import app
 
 
 @app.task(ignore_result=True)
-def task_send_document(body, sender, subject, recipient, user_mailer_id, as_attachment=False, document_id=None):
+def task_send_document(
+    body, sender, subject, recipient, user_mailer_id, as_attachment=False,
+    document_id=None, organization_installation_url=None
+):
     Document = apps.get_model(
         app_label='documents', model_name='Document'
     )
@@ -21,5 +24,6 @@ def task_send_document(body, sender, subject, recipient, user_mailer_id, as_atta
 
     user_mailer.send_document(
         as_attachment=as_attachment, body=body, document=document,
+        organization_installation_url=organization_installation_url,
         subject=subject, to=recipient
     )
