@@ -3,10 +3,8 @@ import json
 from ..models import UserMailer
 
 from .literals import (
-    TEST_EMAIL_ADDRESS,
-    TEST_EMAIL_FROM_ADDRESS,
-    TEST_USER_MAILER_BACKEND_PATH,
-    TEST_USER_MAILER_LABEL
+    TEST_EMAIL_ADDRESS, TEST_EMAIL_FROM_ADDRESS,
+    TEST_USER_MAILER_BACKEND_PATH, TEST_USER_MAILER_LABEL
 )
 
 
