@@ -6,12 +6,13 @@ from django.utils.translation import ungettext, ugettext_lazy as _
 
 from mayan.apps.acls.models import AccessControlList
 from mayan.apps.documents.models import Document
+from mayan.apps.organizations.utils import get_organization_installation_url
 from mayan.apps.views.generics import (
     FormView, MultipleObjectFormActionView, SingleObjectDeleteView,
     SingleObjectDynamicFormCreateView, SingleObjectDynamicFormEditView,
     SingleObjectListView
 )
-from mayan.apps.views.mixins import ExternalObjectMixin
+from mayan.apps.views.mixins import ExternalObjectViewMixin
 
 from .classes import MailerBackend
 from .forms import (
@@ -33,9 +34,9 @@ from .tasks import task_send_document
 class MailDocumentView(MultipleObjectFormActionView):
     as_attachment = True
     form_class = DocumentMailForm
-    model = Document
     object_permission = permission_mailing_send_document
     pk_url_kwarg = 'document_id'
+    source_queryset = Document.valid
     success_message = _('%(count)d document queued for email delivery')
     success_message_plural = _(
         '%(count)d documents queued for email delivery'
@@ -48,7 +49,7 @@ class MailDocumentView(MultipleObjectFormActionView):
         queryset = self.object_list
 
         result = {
-            'submit_icon_class': icon_mail_document_submit,
+            'submit_icon': icon_mail_document_submit,
             'submit_label': _('Send'),
             'title': ungettext(
                 singular=self.title,
@@ -84,10 +85,13 @@ class MailDocumentView(MultipleObjectFormActionView):
                 'as_attachment': self.as_attachment,
                 'body': form.cleaned_data['body'],
                 'document_id': instance.pk,
+                'organization_installation_url': get_organization_installation_url(
+                    request=self.request
+                ),
                 'recipient': form.cleaned_data['email'],
                 'sender': self.request.user.email,
                 'subject': form.cleaned_data['subject'],
-                'user_mailer_id': form.cleaned_data['user_mailer'].pk,
+                'user_mailer_id': form.cleaned_data['user_mailer'].pk
             }
         )
 
@@ -216,7 +220,7 @@ class UserMailerListView(SingleObjectListView):
         return {'fields': self.get_backend().fields}
 
 
-class UserMailerTestView(ExternalObjectMixin, FormView):
+class UserMailerTestView(ExternalObjectViewMixin, FormView):
     external_object_class = UserMailer
     external_object_permission = permission_user_mailer_use
     external_object_pk_url_kwarg = 'mailer_id'
@@ -227,7 +231,7 @@ class UserMailerTestView(ExternalObjectMixin, FormView):
         messages.success(
             message=_('Test email sent.'), request=self.request
         )
-        return super(UserMailerTestView, self).form_valid(form=form)
+        return super().form_valid(form=form)
 
     def get_extra_context(self):
         return {
