@@ -6,6 +6,7 @@ from mayan.apps.documents.permissions import (
     permission_document_type_view, permission_document_type_edit
 )
 from mayan.apps.rest_api import generics
+from mayan.apps.rest_api.api_view_mixins import ExternalObjectAPIViewMixin
 
 from .models import MetadataType
 from .permissions import (
@@ -16,117 +17,79 @@ from .permissions import (
 )
 from .serializers import (
     DocumentMetadataSerializer, DocumentTypeMetadataTypeSerializer,
-    MetadataTypeSerializer, NewDocumentMetadataSerializer,
-    NewDocumentTypeMetadataTypeSerializer,
+    MetadataTypeSerializer, NewDocumentTypeMetadataTypeSerializer,
     WritableDocumentTypeMetadataTypeSerializer
 )
 
 
-class APIDocumentMetadataListView(generics.ListCreateAPIView):
+class APIDocumentMetadataListView(
+    ExternalObjectAPIViewMixin, generics.ListCreateAPIView
+):
     """
     get: Returns a list of selected document's metadata types and values.
     post: Add an existing metadata type and value to the selected document.
     """
-    mayan_object_permissions = {
+    external_object_queryset = Document.valid
+    external_object_pk_url_kwarg = 'document_id'
+    mayan_external_object_permissions = {
         'GET': (permission_document_metadata_view,),
+        'POST': (permission_document_metadata_add,)
     }
-
-    def get_document(self):
-        if self.request.method == 'GET':
-            permission = permission_document_metadata_view
-        elif self.request.method == 'POST':
-            permission = permission_document_metadata_add
-
-        queryset = AccessControlList.objects.restrict_queryset(
-            queryset=Document.objects.all(), permission=permission,
-            user=self.request.user
-        )
-
-        return get_object_or_404(
-            klass=queryset, pk=self.kwargs['document_pk']
-        )
+    mayan_object_permissions = {
+        'GET': (permission_document_metadata_view,)
+    }
+    ordering_fields = ('metadata_type', 'value')
+    serializer_class = DocumentMetadataSerializer
 
     def get_queryset(self):
-        return self.get_document().metadata.all()
+        return self.external_object.metadata.all()
 
-    def get_serializer(self, *args, **kwargs):
-        if not self.request:
-            return None
-
-        return super(APIDocumentMetadataListView, self).get_serializer(*args, **kwargs)
-
-    def get_serializer_class(self):
-        if self.request.method == 'GET':
-            return DocumentMetadataSerializer
-        else:
-            return NewDocumentMetadataSerializer
-
-    def get_serializer_context(self):
-        """
-        Extra context provided to the serializer class.
-        """
-        context = super(APIDocumentMetadataListView, self).get_serializer_context()
-        if self.kwargs:
-            context.update(
-                {
-                    'document': self.get_document(),
-                }
-            )
-
-        return context
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user,
+            'document': self.external_object
+        }
 
     def perform_create(self, serializer):
-        serializer.save(document=self.get_document())
+        if 'metadata_type_id' in serializer.validated_data:
+            serializer.validated_data['metadata_type'] = serializer.validated_data['metadata_type_id']
+
+        return super().perform_create(serializer=serializer)
 
 
-class APIDocumentMetadataView(generics.RetrieveUpdateDestroyAPIView):
+class APIDocumentMetadataView(
+    ExternalObjectAPIViewMixin, generics.RetrieveUpdateDestroyAPIView
+):
     """
     delete: Remove this metadata entry from the selected document.
     get: Return the details of the selected document metadata type and value.
     patch: Edit the selected document metadata type and value.
     put: Edit the selected document metadata type and value.
     """
-    lookup_url_kwarg = 'metadata_pk'
+    external_object_queryset = Document.valid
+    external_object_pk_url_kwarg = 'document_id'
+    lookup_url_kwarg = 'metadata_id'
+    mayan_external_object_permissions = {
+        'DELETE': (permission_document_metadata_remove,),
+        'GET': (permission_document_metadata_view,),
+        'PATCH': (permission_document_metadata_edit,),
+        'PUT': (permission_document_metadata_edit,)
+    }
     mayan_object_permissions = {
         'DELETE': (permission_document_metadata_remove,),
         'GET': (permission_document_metadata_view,),
         'PATCH': (permission_document_metadata_edit,),
         'PUT': (permission_document_metadata_edit,)
     }
+    serializer_class = DocumentMetadataSerializer
 
-    def get_document(self):
-        if self.request.method == 'GET':
-            permission = permission_document_metadata_view
-        elif self.request.method == 'PUT':
-            permission = permission_document_metadata_edit
-        elif self.request.method == 'PATCH':
-            permission = permission_document_metadata_edit
-        elif self.request.method == 'DELETE':
-            permission = permission_document_metadata_remove
-
-        queryset = AccessControlList.objects.restrict_queryset(
-            queryset=Document.objects.all(), permission=permission,
-            user=self.request.user
-        )
-
-        return get_object_or_404(
-            klass=queryset, pk=self.kwargs['document_pk']
-        )
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user,
+        }
 
     def get_queryset(self):
-        return self.get_document().metadata.all()
-
-    def get_serializer(self, *args, **kwargs):
-        if not self.request:
-            return None
-
-        return super(APIDocumentMetadataView, self).get_serializer(*args, **kwargs)
-
-    def get_serializer_class(self):
-        if self.request.method == 'GET':
-            return DocumentMetadataSerializer
-        else:
-            return DocumentMetadataSerializer
+        return self.external_object.metadata.all()
 
 
 class APIMetadataTypeListView(generics.ListCreateAPIView):
@@ -136,9 +99,15 @@ class APIMetadataTypeListView(generics.ListCreateAPIView):
     """
     mayan_object_permissions = {'GET': (permission_metadata_type_view,)}
     mayan_view_permissions = {'POST': (permission_metadata_type_create,)}
+    ordering_fields = ('label', 'name')
     queryset = MetadataType.objects.all()
     serializer_class = MetadataTypeSerializer
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
 
 class APIMetadataTypeView(generics.RetrieveUpdateDestroyAPIView):
     """
@@ -147,7 +116,7 @@ class APIMetadataTypeView(generics.RetrieveUpdateDestroyAPIView):
     patch: Edit the selected metadata type.
     put: Edit the selected metadata type.
     """
-    lookup_url_kwarg = 'metadata_type_pk'
+    lookup_url_kwarg = 'metadata_type_id'
     mayan_object_permissions = {
         'GET': (permission_metadata_type_view,),
         'PUT': (permission_metadata_type_edit,),
@@ -157,13 +126,18 @@ class APIMetadataTypeView(generics.RetrieveUpdateDestroyAPIView):
     queryset = MetadataType.objects.all()
     serializer_class = MetadataTypeSerializer
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
 
 class APIDocumentTypeMetadataTypeListView(generics.ListCreateAPIView):
     """
     get: Returns a list of selected document type's metadata types.
     post: Add a metadata type to the selected document type.
     """
-    lookup_url_kwarg = 'metadata_type_pk'
+    lookup_url_kwarg = 'metadata_type_id'
 
     def get_document_type(self):
         if self.request.method == 'GET':
@@ -172,7 +146,7 @@ class APIDocumentTypeMetadataTypeListView(generics.ListCreateAPIView):
             permission_required = permission_document_type_edit
 
         document_type = get_object_or_404(
-            klass=DocumentType, pk=self.kwargs['document_type_pk']
+            klass=DocumentType, pk=self.kwargs['document_type_id']
         )
 
         AccessControlList.objects.check_access(
@@ -182,6 +156,11 @@ class APIDocumentTypeMetadataTypeListView(generics.ListCreateAPIView):
 
         return document_type
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
     def get_queryset(self):
         return self.get_document_type().metadata.all()
 
@@ -189,9 +168,7 @@ class APIDocumentTypeMetadataTypeListView(generics.ListCreateAPIView):
         if not self.request:
             return None
 
-        return super(
-            APIDocumentTypeMetadataTypeListView, self
-        ).get_serializer(*args, **kwargs)
+        return super().get_serializer(*args, **kwargs)
 
     def get_serializer_class(self):
         if self.request.method == 'GET':
@@ -203,7 +180,7 @@ class APIDocumentTypeMetadataTypeListView(generics.ListCreateAPIView):
         """
         Extra context provided to the serializer class.
         """
-        context = super(APIDocumentTypeMetadataTypeListView, self).get_serializer_context()
+        context = super().get_serializer_context()
         if self.kwargs:
             context.update(
                 {
@@ -221,7 +198,7 @@ class APIDocumentTypeMetadataTypeView(generics.RetrieveUpdateDestroyAPIView):
     patch: Edit the selected document type metadata type.
     put: Edit the selected document type metadata type.
     """
-    lookup_url_kwarg = 'metadata_type_pk'
+    lookup_url_kwarg = 'metadata_type_id'
     serializer_class = DocumentTypeMetadataTypeSerializer
 
     def get_document_type(self):
@@ -231,7 +208,7 @@ class APIDocumentTypeMetadataTypeView(generics.RetrieveUpdateDestroyAPIView):
             permission_required = permission_document_type_edit
 
         document_type = get_object_or_404(
-            klass=DocumentType, pk=self.kwargs['document_type_pk']
+            klass=DocumentType, pk=self.kwargs['document_type_id']
         )
 
         AccessControlList.objects.check_access(
@@ -241,6 +218,11 @@ class APIDocumentTypeMetadataTypeView(generics.RetrieveUpdateDestroyAPIView):
 
         return document_type
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
     def get_queryset(self):
         return self.get_document_type().metadata.all()
 
@@ -248,7 +230,7 @@ class APIDocumentTypeMetadataTypeView(generics.RetrieveUpdateDestroyAPIView):
         if not self.request:
             return None
 
-        return super(APIDocumentTypeMetadataTypeView, self).get_serializer(*args, **kwargs)
+        return super().get_serializer(*args, **kwargs)
 
     def get_serializer_class(self):
         if self.request.method == 'GET':
