@@ -5,15 +5,15 @@ from django.utils.text import format_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.templating.fields import TemplateField
+from mayan.apps.views.forms import RelationshipForm
 
 from .classes import MetadataLookup
-from .models import DocumentTypeMetadataType, MetadataType
+from .models import MetadataType
 
 
 class DocumentMetadataForm(forms.Form):
-    id = forms.CharField(label=_('ID'), widget=forms.HiddenInput)
-
-    name = forms.CharField(
+    metadata_type_id = forms.CharField(label=_('ID'), widget=forms.HiddenInput)
+    metadata_type_name = forms.CharField(
         label=_('Name'), required=False,
         widget=forms.TextInput(attrs={'readonly': 'readonly'})
     )
@@ -30,7 +30,7 @@ class DocumentMetadataForm(forms.Form):
         js = ('metadata/js/metadata_form.js',)
 
     def __init__(self, *args, **kwargs):
-        super(DocumentMetadataForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         # Set form fields initial values
         if 'initial' in kwargs:
@@ -49,13 +49,13 @@ class DocumentMetadataForm(forms.Form):
                 self.fields['value'].required = False
                 self.fields['update'].initial = False
 
-            self.fields['name'].initial = '%s%s' % (
+            self.fields['metadata_type_name'].initial = '%s%s' % (
                 (
                     self.metadata_type.label if self.metadata_type.label else self.metadata_type.name
                 ),
                 required_string
             )
-            self.fields['id'].initial = self.metadata_type.pk
+            self.fields['metadata_type_id'].initial = self.metadata_type.pk
 
             if self.metadata_type.lookup:
                 try:
@@ -99,7 +99,9 @@ class DocumentMetadataForm(forms.Form):
             required = self.metadata_type.get_required_for(
                 document_type=self.document_type
             )
-            if required and not self.cleaned_data.get('update'):
+
+            # Enforce required only if the metadata has no previous value.
+            if required and not self.cleaned_data.get('value') and not self.cleaned_data.get('update'):
                 raise ValidationError(
                     _(
                         '"%s" is required for this document type.'
@@ -115,7 +117,7 @@ class DocumentMetadataForm(forms.Form):
         return self.cleaned_data
 
 
-DocumentMetadataFormSet = formset_factory(DocumentMetadataForm, extra=0)
+DocumentMetadataFormSet = formset_factory(form=DocumentMetadataForm, extra=0)
 
 
 class DocumentMetadataAddForm(forms.Form):
@@ -139,7 +141,7 @@ class DocumentMetadataAddForm(forms.Form):
         else:
             queryset = MetadataType.objects.none()
 
-        super(DocumentMetadataAddForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         self.fields['metadata_type'].queryset = queryset
 
@@ -150,7 +152,7 @@ class DocumentMetadataRemoveForm(DocumentMetadataForm):
     )
 
     def __init__(self, *args, **kwargs):
-        super(DocumentMetadataRemoveForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.fields.pop('value')
 
     def clean(self):
@@ -158,13 +160,13 @@ class DocumentMetadataRemoveForm(DocumentMetadataForm):
 
 
 DocumentMetadataRemoveFormSet = formset_factory(
-    DocumentMetadataRemoveForm, extra=0
+    form=DocumentMetadataRemoveForm, extra=0
 )
 
 
 class MetadataTypeForm(forms.ModelForm):
     def __init__(self, *args, **kwargs):
-        super(MetadataTypeForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.fields['default'] = TemplateField(
             initial_help_text=self.fields['default'].help_text, required=False
         )
@@ -182,7 +184,7 @@ class MetadataTypeForm(forms.ModelForm):
         model = MetadataType
 
 
-class DocumentTypeMetadataTypeRelationshipForm(forms.Form):
+class DocumentTypeMetadataTypeRelationshipForm(RelationshipForm):
     RELATIONSHIP_TYPE_NONE = 'none'
     RELATIONSHIP_TYPE_OPTIONAL = 'optional'
     RELATIONSHIP_TYPE_REQUIRED = 'required'
@@ -192,97 +194,42 @@ class DocumentTypeMetadataTypeRelationshipForm(forms.Form):
         (RELATIONSHIP_TYPE_REQUIRED, _('Required')),
     )
 
-    label = forms.CharField(
-        label=_('Label'), required=False,
-        widget=forms.TextInput(attrs={'readonly': 'readonly'})
-    )
-    relationship_type = forms.ChoiceField(
-        label=_('Relationship'),
-        widget=forms.RadioSelect(), choices=RELATIONSHIP_CHOICES
-    )
-
-    def __init__(self, *args, **kwargs):
-        self._user = kwargs.pop('_user')
-        super(DocumentTypeMetadataTypeRelationshipForm, self).__init__(
-            *args, **kwargs
-        )
-
-        if 'main_model' in self.initial:
-            if self.initial['main_model'] == 'metadata_type':
-                self.fields['label'].initial = self.initial['document_type'].label
-            else:
-                self.fields['label'].initial = self.initial['metadata_type'].label
-
-            self.initial_relationship_type = self.get_relationship_type()
-            self.fields['relationship_type'].initial = self.initial_relationship_type
-
-    def get_relationship(self):
-        return self.initial['document_type'].metadata.filter(
-            metadata_type=self.initial['metadata_type']
-        )
-
-    def get_relationship_choices(self):
-        return self.initial['document_type'].metadata.filter(
-            metadata_type=self.initial['metadata_type']
-        )
-
     def get_relationship_type(self):
-        relationship = self.get_relationship()
+        relationship_queryset = self.get_relationship_queryset()
 
-        if relationship.exists():
-            if relationship.get().required:
+        if relationship_queryset.exists():
+            if relationship_queryset.get().required:
                 return self.RELATIONSHIP_TYPE_REQUIRED
             else:
                 return self.RELATIONSHIP_TYPE_OPTIONAL
         else:
             return self.RELATIONSHIP_TYPE_NONE
 
-    def save(self):
-        relationship = self.get_relationship()
+    def save_relationship_none(self):
+        instance = self.get_relationship_instance()
+        instance._event_actor = self._event_actor
+        instance.delete()
 
-        if self.cleaned_data['relationship_type'] != self.initial_relationship_type:
-            getattr(
-                self, 'save_relationship_{}'.format(
-                    self.cleaned_data['relationship_type']
-                )
-            )(relationship=relationship)
+    def save_relationship_optional(self):
+        instance = self.get_relationship_instance()
+        instance.required = False
+        instance._event_actor = self._event_actor
+        instance.save()
 
-    def save_relationship_none(self, relationship):
-        relationship.get().delete(_user=self._user)
-
-    def save_relationship_optional(self, relationship):
-        if relationship.exists():
-            instance = relationship.get()
-            instance.required = False
-            instance.save(_user=self._user)
-        else:
-            relationship = DocumentTypeMetadataType(
-                document_type=self.initial['document_type'],
-                metadata_type=self.initial['metadata_type'],
-            )
-            relationship.save(_user=self._user)
-
-    def save_relationship_required(self, relationship):
-        if relationship.exists():
-            instance = relationship.get()
-            instance.required = True
-            instance.save(_user=self._user)
-        else:
-            relationship = DocumentTypeMetadataType(
-                document_type=self.initial['document_type'],
-                metadata_type=self.initial['metadata_type'],
-                required=True,
-            )
-            relationship.save(_user=self._user)
+    def save_relationship_required(self):
+        instance = self.get_relationship_instance()
+        instance.required = True
+        instance._event_actor = self._event_actor
+        instance.save()
 
 
 DocumentTypeMetadataTypeRelationshipFormSetBase = formset_factory(
-    DocumentTypeMetadataTypeRelationshipForm, extra=0
+    form=DocumentTypeMetadataTypeRelationshipForm, extra=0
 )
 
 
 class DocumentTypeMetadataTypeRelationshipFormSet(DocumentTypeMetadataTypeRelationshipFormSetBase):
     def __init__(self, *args, **kwargs):
-        _user = kwargs.pop('_user')
-        super(DocumentTypeMetadataTypeRelationshipFormSet, self).__init__(*args, **kwargs)
-        self.form_kwargs.update({'_user': _user})
+        _event_actor = kwargs.pop('_event_actor')
+        super().__init__(*args, **kwargs)
+        self.form_kwargs.update({'_event_actor': _event_actor})
