@@ -1,37 +1,37 @@
-import copy
+from django.db.models import Q
 
-from ..models import MetadataType
+from ..models import DocumentTypeMetadataType, MetadataType
 
 from .literals import (
-    TEST_METADATA_TYPE_LABEL_EDITED, TEST_METADATA_TYPE_NAME_EDITED,
-    TEST_METADATA_TYPES_FIXTURES, TEST_METADATA_VALUE,
-    TEST_METADATA_VALUE_EDITED
+    TEST_METADATA_TYPE_LABEL, TEST_METADATA_TYPE_LABEL_EDITED,
+    TEST_METADATA_TYPE_NAME, TEST_METADATA_TYPE_NAME_EDITED,
+    TEST_METADATA_VALUE, TEST_METADATA_VALUE_EDITED
 )
 
 
 class DocumentMetadataAPIViewTestMixin:
-    def _request_document_metadata_create_view(self, extra_data=None):
+    def _request_document_metadata_create_api_view(self, extra_data=None):
         data = {
-            'metadata_type_pk': self.test_metadata_type.pk,
+            'metadata_type_id': self.test_metadata_type.pk,
             'value': TEST_METADATA_VALUE
         }
         data.update(extra_data or {})
 
         return self.post(
             viewname='rest_api:documentmetadata-list',
-            kwargs={'document_pk': self.test_document.pk}, data=data
+            kwargs={'document_id': self.test_document.pk}, data=data
         )
 
-    def _request_document_metadata_delete_view(self):
+    def _request_document_metadata_delete_api_view(self):
         return self.delete(
             viewname='rest_api:documentmetadata-detail',
             kwargs={
-                'document_pk': self.test_document.pk,
-                'metadata_pk': self.test_document_metadata.pk
+                'document_id': self.test_document.pk,
+                'metadata_id': self.test_document_metadata.pk
             }
         )
 
-    def _request_document_metadata_edit_view_via_patch(self, extra_data=None):
+    def _request_document_metadata_edit_api_view_via_patch(self, extra_data=None):
         data = {
             'value': TEST_METADATA_VALUE_EDITED
         }
@@ -40,12 +40,12 @@ class DocumentMetadataAPIViewTestMixin:
         return self.patch(
             viewname='rest_api:documentmetadata-detail',
             kwargs={
-                'document_pk': self.test_document.pk,
-                'metadata_pk': self.test_document_metadata.pk
+                'document_id': self.test_document.pk,
+                'metadata_id': self.test_document_metadata.pk
             }, data=data
         )
 
-    def _request_document_metadata_edit_view_via_put(self, extra_data=None):
+    def _request_document_metadata_edit_api_view_via_put(self, extra_data=None):
         data = {
             'value': TEST_METADATA_VALUE_EDITED
         }
@@ -54,15 +54,15 @@ class DocumentMetadataAPIViewTestMixin:
         return self.put(
             viewname='rest_api:documentmetadata-detail',
             kwargs={
-                'document_pk': self.test_document.pk,
-                'metadata_pk': self.test_document_metadata.pk
+                'document_id': self.test_document.pk,
+                'metadata_id': self.test_document_metadata.pk
             }, data=data
         )
 
-    def _request_document_metadata_list_view(self):
+    def _request_document_metadata_list_api_view(self):
         return self.get(
             viewname='rest_api:documentmetadata-list', kwargs={
-                'document_pk': self.test_document.pk
+                'document_id': self.test_document.pk
             }
         )
 
@@ -100,18 +100,25 @@ class DocumentMetadataViewTestMixin:
             }
         )
 
-    def _request_test_document_metadata_edit_post_view(self):
+    def _request_test_document_metadata_edit_post_view(
+        self, extra_data=None, follow=False
+    ):
+        data = {
+            'form-0-metadata_type_id': self.test_metadata_type.pk,
+            'form-0-update': True,
+            'form-0-value': TEST_METADATA_VALUE_EDITED,
+            'form-TOTAL_FORMS': '1',
+            'form-INITIAL_FORMS': '0',
+            'form-MAX_NUM_FORMS': '',
+        }
+
+        if extra_data:
+            data.update(extra_data)
+
         return self.post(
             viewname='metadata:metadata_edit', kwargs={
                 'document_id': self.test_document.pk
-            }, data={
-                'form-0-id': self.test_metadata_type.pk,
-                'form-0-update': True,
-                'form-0-value': TEST_METADATA_VALUE_EDITED,
-                'form-TOTAL_FORMS': '1',
-                'form-INITIAL_FORMS': '0',
-                'form-MAX_NUM_FORMS': '',
-            }
+            }, data=data, follow=follow
         )
 
     def _request_test_document_metadata_list_view(self):
@@ -132,7 +139,7 @@ class DocumentMetadataViewTestMixin:
         return self.post(
             viewname='metadata:metadata_remove',
             kwargs={'document_id': self.test_document.pk}, data={
-                'form-0-id': self.test_metadata_types[index].pk,
+                'form-0-metadata_type_id': self.test_metadata_types[index].pk,
                 'form-0-update': True,
                 'form-TOTAL_FORMS': '1',
                 'form-INITIAL_FORMS': '0',
@@ -150,13 +157,22 @@ class DocumentMetadataViewTestMixin:
             }
         )
 
+    def _request_test_document_multiple_metadata_edit_get_view(self):
+        return self.get(
+            viewname='metadata:metadata_multiple_edit', data={
+                'id_list': '{},{}'.format(
+                    self.test_documents[0].pk, self.test_documents[1].pk
+                )
+            }
+        )
+
     def _request_test_document_multiple_metadata_edit_post_view(self):
         return self.post(
             viewname='metadata:metadata_multiple_edit', data={
                 'id_list': '{},{}'.format(
                     self.test_documents[0].pk, self.test_documents[1].pk
                 ),
-                'form-0-id': self.test_metadata_type.pk,
+                'form-0-metadata_type_id': self.test_metadata_type.pk,
                 'form-0-update': True,
                 'form-0-value': TEST_METADATA_VALUE_EDITED,
                 'form-TOTAL_FORMS': '1',
@@ -165,13 +181,22 @@ class DocumentMetadataViewTestMixin:
             }
         )
 
+    def _request_test_document_multiple_metadata_remove_get_view(self):
+        return self.get(
+            viewname='metadata:metadata_multiple_remove', data={
+                'id_list': '{},{}'.format(
+                    self.test_documents[0].pk, self.test_documents[0].pk
+                )
+            }
+        )
+
     def _request_test_document_multiple_metadata_remove_post_view(self):
         return self.post(
             viewname='metadata:metadata_multiple_remove', data={
                 'id_list': '{},{}'.format(
                     self.test_documents[0].pk, self.test_documents[1].pk
                 ),
-                'form-0-id': self.test_metadata_type.pk,
+                'form-0-metadata_type_id': self.test_metadata_type.pk,
                 'form-0-update': True,
                 'form-TOTAL_FORMS': '1',
                 'form-INITIAL_FORMS': '0',
@@ -181,47 +206,59 @@ class DocumentMetadataViewTestMixin:
 
 
 class DocumentTypeMetadataTypeAPIViewTestMixin:
-    def _request_document_type_metadata_type_create_view(self):
-        return self.post(
+    def _request_document_type_metadata_type_create_api_view(self):
+        pk_list = list(DocumentTypeMetadataType.objects.values_list('pk', flat=True))
+
+        response = self.post(
             viewname='rest_api:documenttypemetadatatype-list',
-            kwargs={'document_type_pk': self.test_document_type.pk}, data={
-                'metadata_type_pk': self.test_metadata_type.pk, 'required': False
+            kwargs={'document_type_id': self.test_document_type.pk}, data={
+                'metadata_type_id': self.test_metadata_type.pk,
+                'required': False
             }
         )
 
-    def _request_document_type_metadata_type_delete_view(self):
+        try:
+            self.test_document_type_metadata_type = DocumentTypeMetadataType.objects.get(
+                ~Q(pk__in=pk_list)
+            )
+        except DocumentTypeMetadataType.DoesNotExist:
+            self.test_document_type_metadata_type = None
+
+        return response
+
+    def _request_document_type_metadata_type_delete_api_view(self):
         return self.delete(
             viewname='rest_api:documenttypemetadatatype-detail',
             kwargs={
-                'document_type_pk': self.test_document_type.pk,
-                'metadata_type_pk': self.test_document_type_metadata_type.pk
+                'document_type_id': self.test_document_type.pk,
+                'metadata_type_id': self.test_document_type_metadata_type.pk
             }
         )
 
-    def _request_document_type_metadata_type_list_view(self):
+    def _request_document_type_metadata_type_list_api_view(self):
         return self.get(
             viewname='rest_api:documenttypemetadatatype-list', kwargs={
-                'document_type_pk': self.test_document_type.pk
+                'document_type_id': self.test_document_type.pk
             }
         )
 
-    def _request_document_type_metadata_type_edit_view_via_patch(self):
+    def _request_document_type_metadata_type_edit_api_view_via_patch(self):
         return self.patch(
             viewname='rest_api:documenttypemetadatatype-detail',
             kwargs={
-                'document_type_pk': self.test_document_type.pk,
-                'metadata_type_pk': self.test_document_type_metadata_type.pk
+                'document_type_id': self.test_document_type.pk,
+                'metadata_type_id': self.test_document_type_metadata_type.pk
             }, data={
                 'required': True
             }
         )
 
-    def _request_document_type_metadata_type_edit_view_via_put(self):
+    def _request_document_type_metadata_type_edit_api_view_via_put(self):
         return self.put(
             viewname='rest_api:documenttypemetadatatype-detail',
             kwargs={
-                'document_type_pk': self.test_document_type.pk,
-                'metadata_type_pk': self.test_document_type_metadata_type.pk
+                'document_type_id': self.test_document_type.pk,
+                'metadata_type_id': self.test_document_type_metadata_type.pk
             }, data={
                 'required': True
             }
@@ -229,59 +266,63 @@ class DocumentTypeMetadataTypeAPIViewTestMixin:
 
 
 class MetadataTypeAPIViewTestMixin:
-    def setUp(self):
-        super(MetadataTypeAPIViewTestMixin, self).setUp()
-        self.test_metadata_types_fixtures_api_views = copy.copy(
-            TEST_METADATA_TYPES_FIXTURES
+    def _request_test_metadata_type_create_api_view(self):
+        pk_list = list(MetadataType.objects.values('pk'))
+
+        response = self.post(
+            viewname='rest_api:metadatatype-list', data={
+                'name': 'test_metadata_type', 'label': 'test metadata type'
+            }
         )
 
-    def _request_test_metadata_type_create_view(self):
-        return self.post(
-            viewname='rest_api:metadatatype-list',
-            data=self.test_metadata_types_fixtures_api_views.pop()
-        )
+        try:
+            self.test_metadata_type = MetadataType.objects.get(
+                ~Q(pk__in=pk_list)
+            )
+        except MetadataType.DoesNotExist:
+            self.test_metadata_type = None
 
-    def _request_test_metadata_type_delete_view(self):
+        return response
+
+    def _request_test_metadata_type_delete_api_view(self):
         return self.delete(
             viewname='rest_api:metadatatype-detail',
-            kwargs={'metadata_type_pk': self.test_metadata_type.pk}
+            kwargs={'metadata_type_id': self.test_metadata_type.pk}
         )
 
-    def _request_test_metadata_type_detail_view(self):
+    def _request_test_metadata_type_detail_api_view(self):
         return self.get(
             viewname='rest_api:metadatatype-detail',
-            kwargs={'metadata_type_pk': self.test_metadata_type.pk}
+            kwargs={'metadata_type_id': self.test_metadata_type.pk}
         )
 
-    def _request_test_metadata_type_edit_view_via_patch(self):
+    def _request_test_metadata_type_edit_api_view_via_patch(self):
         return self.patch(
             viewname='rest_api:metadatatype-detail',
-            kwargs={'metadata_type_pk': self.test_metadata_type.pk}, data={
+            kwargs={'metadata_type_id': self.test_metadata_type.pk}, data={
                 'label': '{} edited'.format(self.test_metadata_type.label),
                 'name': '{}_edited'.format(self.test_metadata_type.name),
             }
         )
 
-    def _request_test_metadata_type_edit_view_via_put(self):
+    def _request_test_metadata_type_edit_api_view_via_put(self):
         return self.put(
             viewname='rest_api:metadatatype-detail',
-            kwargs={'metadata_type_pk': self.test_metadata_type.pk}, data={
+            kwargs={'metadata_type_id': self.test_metadata_type.pk}, data={
                 'label': '{} edited'.format(self.test_metadata_type.label),
                 'name': '{}_edited'.format(self.test_metadata_type.name),
             }
         )
 
-    def _request_test_metadata_type_list_view(self):
+    def _request_test_metadata_type_list_api_view(self):
         return self.get(viewname='rest_api:metadatatype-list')
 
 
 class MetadataTypeTestMixin:
     def setUp(self):
-        super(MetadataTypeTestMixin, self).setUp()
-        self.test_metadata_types_fixtures_models = copy.copy(
-            TEST_METADATA_TYPES_FIXTURES
-        )
+        super().setUp()
         self.test_metadata_types = []
+        self._test_document_type_metadata_type_relationships = []
 
     def _get_test_metadata_type_queryset(self):
         return MetadataType.objects.filter(
@@ -290,18 +331,42 @@ class MetadataTypeTestMixin:
             ]
         )
 
-    def _create_test_metadata_type(self):
+    def _create_test_metadata_type(
+        self, add_test_document_type=False, required=False
+    ):
+        total_test_metadata_types = len(self.test_metadata_types)
+        name = '{}_{}'.format(
+            TEST_METADATA_TYPE_NAME, total_test_metadata_types
+        )
+        label = '{}_{}'.format(
+            TEST_METADATA_TYPE_LABEL, total_test_metadata_types
+        )
+
         self.test_metadata_type = MetadataType.objects.create(
-            **self.test_metadata_types_fixtures_models.pop()
+            name=name, label=label
         )
         self.test_metadata_types.append(self.test_metadata_type)
 
+        if add_test_document_type:
+            self._test_document_type_metadata_type_relationships.append(
+                self.test_document_type.metadata.create(
+                    metadata_type=self.test_metadata_type, required=required
+                )
+            )
+
 
 class MetadataTypeViewTestMixin:
-    def setUp(self):
-        super(MetadataTypeViewTestMixin, self).setUp()
-        self.test_metadata_types_fixtures_views = copy.copy(
-            TEST_METADATA_TYPES_FIXTURES
+    def _request_test_document_type_relationship_delete_view(self):
+        # This request assumes there is only one document type and
+        # blindly sets the first form of the formset.
+
+        return self.post(
+            viewname='metadata:document_type_metadata_type_relationship',
+            kwargs={'document_type_id': self.test_document_type.pk}, data={
+                'form-TOTAL_FORMS': '1',
+                'form-INITIAL_FORMS': '0',
+                'form-0-relationship_type': 'none'
+            }
         )
 
     def _request_test_document_type_relationship_edit_view(self):
@@ -309,7 +374,7 @@ class MetadataTypeViewTestMixin:
         # blindly sets the first form of the formset.
 
         return self.post(
-            viewname='metadata:setup_document_type_metadata_types',
+            viewname='metadata:document_type_metadata_type_relationship',
             kwargs={'document_type_id': self.test_document_type.pk}, data={
                 'form-TOTAL_FORMS': '1',
                 'form-INITIAL_FORMS': '0',
@@ -319,20 +384,21 @@ class MetadataTypeViewTestMixin:
 
     def _request_test_metadata_type_create_view(self):
         return self.post(
-            viewname='metadata:setup_metadata_type_create',
-            data=self.test_metadata_types_fixtures_views.pop()
+            viewname='metadata:metadata_type_create', data={
+                'name': 'test_metadata_type', 'label': 'test metadata type'
+            }
         )
 
     def _request_test_metadata_type_delete_view(self):
         return self.post(
-            viewname='metadata:setup_metadata_type_delete', kwargs={
+            viewname='metadata:metadata_type_delete', kwargs={
                 'metadata_type_id': self.test_metadata_type.pk
             }
         )
 
     def _request_test_metadata_type_edit_view(self):
         return self.post(
-            viewname='metadata:setup_metadata_type_edit', kwargs={
+            viewname='metadata:metadata_type_edit', kwargs={
                 'metadata_type_id': self.test_metadata_type.pk
             }, data={
                 'label': TEST_METADATA_TYPE_LABEL_EDITED,
@@ -342,15 +408,28 @@ class MetadataTypeViewTestMixin:
 
     def _request_metadata_type_list_view(self):
         return self.get(
-            viewname='metadata:setup_metadata_type_list',
+            viewname='metadata:metadata_type_list',
         )
 
-    def _request_test_metadata_type_relationship_edit_view(self):
+    def _request_test_metadata_type_document_type_relationship_delete_view(self):
         # This request assumes there is only one document type and
         # blindly sets the first form of the formset.
 
         return self.post(
-            viewname='metadata:setup_metadata_type_document_types',
+            viewname='metadata:metadata_type_document_type_relationship',
+            kwargs={'metadata_type_id': self.test_metadata_type.pk}, data={
+                'form-TOTAL_FORMS': '1',
+                'form-INITIAL_FORMS': '0',
+                'form-0-relationship_type': 'none'
+            }
+        )
+
+    def _request_test_metadata_type_document_type_relationship_edit_view(self):
+        # This request assumes there is only one document type and
+        # blindly sets the first form of the formset.
+
+        return self.post(
+            viewname='metadata:metadata_type_document_type_relationship',
             kwargs={'metadata_type_id': self.test_metadata_type.pk}, data={
                 'form-TOTAL_FORMS': '1',
                 'form-INITIAL_FORMS': '0',
