@@ -29,14 +29,14 @@ class Tesseract(OCRBackendBase):
         """
         Execute the command line binary of tesseract
         """
-        super(Tesseract, self).execute(*args, **kwargs)
+        super().execute(*args, **kwargs)
 
         if self.command_tesseract:
             image = self.converter.get_page()
 
             try:
                 temporary_image_file = TemporaryFile()
-                shutil.copyfileobj(image, temporary_image_file)
+                shutil.copyfileobj(fsrc=image, fdst=temporary_image_file)
                 temporary_image_file.seek(0)
 
                 arguments = ['-', '-']
@@ -57,7 +57,7 @@ class Tesseract(OCRBackendBase):
                     result = self.command_tesseract(
                         *arguments, **keyword_arguments
                     )
-                    return force_text(result.stdout)
+                    return force_text(s=result.stdout)
                 except Exception as exception:
                     error_message = (
                         'Exception calling Tesseract with language option: {}; {}'
@@ -71,7 +71,7 @@ class Tesseract(OCRBackendBase):
                             error_message, self.language
                         )
 
-                    logger.error(error_message)
+                    logger.error(error_message, exc_info=True)
                     raise OCRError(error_message)
                 else:
                     return result
@@ -104,7 +104,7 @@ class Tesseract(OCRBackendBase):
 
             # Extaction: strip last line, split by newline, discard the first
             # line
-            self.languages = force_text(result.stdout).strip().split('\n')[1:]
+            self.languages = force_text(s=result.stdout).strip().split('\n')[1:]
 
             logger.debug('Available languages: %s', ', '.join(self.languages))
 
