@@ -2,14 +2,16 @@ from django.db import models
 from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.documents.models import DocumentPage, DocumentType, DocumentVersion
+from mayan.apps.documents.models.document_type_models import DocumentType
+from mayan.apps.documents.models.document_version_models import DocumentVersion
+from mayan.apps.documents.models.document_version_page_models import DocumentVersionPage
 
 from .managers import (
-    DocumentPageOCRContentManager, DocumentTypeSettingsManager
+    DocumentVersionPageOCRContentManager, DocumentTypeSettingsManager
 )
 
 
-class DocumentTypeSettings(models.Model):
+class DocumentTypeOCRSettings(models.Model):
     """
     Model to store the OCR settings for a document type.
     """
@@ -33,34 +35,10 @@ class DocumentTypeSettings(models.Model):
     natural_key.dependencies = ['documents.DocumentType']
 
 
-class DocumentPageOCRContent(models.Model):
-    """
-    This model stores the OCR results for a document page.
-    """
-    document_page = models.OneToOneField(
-        on_delete=models.CASCADE, related_name='ocr_content',
-        to=DocumentPage, verbose_name=_('Document page')
-    )
-    content = models.TextField(
-        blank=True, help_text=_(
-            'The actual text content extracted by the OCR backend.'
-        ), verbose_name=_('Content')
-    )
-
-    objects = DocumentPageOCRContentManager()
-
-    class Meta:
-        verbose_name = _('Document page OCR content')
-        verbose_name_plural = _('Document pages OCR contents')
-
-    def __str__(self):
-        return force_text(self.document_page)
-
-
 class DocumentVersionOCRError(models.Model):
     """
     This models keeps track of the errors captured during the OCR of a
-    document version.
+    document version page images.
     """
     document_version = models.ForeignKey(
         on_delete=models.CASCADE, related_name='ocr_errors',
@@ -77,4 +55,28 @@ class DocumentVersionOCRError(models.Model):
         verbose_name_plural = _('Document version OCR errors')
 
     def __str__(self):
-        return force_text(self.document_version)
+        return force_text(s=self.document_version)
+
+
+class DocumentVersionPageOCRContent(models.Model):
+    """
+    This model stores the OCR results for a document version page.
+    """
+    document_version_page = models.OneToOneField(
+        on_delete=models.CASCADE, related_name='ocr_content',
+        to=DocumentVersionPage, verbose_name=_('Document version page')
+    )
+    content = models.TextField(
+        blank=True, help_text=_(
+            'The actual text content extracted by the OCR backend.'
+        ), verbose_name=_('Content')
+    )
+
+    objects = DocumentVersionPageOCRContentManager()
+
+    class Meta:
+        verbose_name = _('Document version page OCR content')
+        verbose_name_plural = _('Document version pages OCR contents')
+
+    def __str__(self):
+        return force_text(s=self.document_version_page)
