@@ -1,16 +1,16 @@
 from rest_framework import status
 
-from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.documents.tests.mixins.document_mixins import DocumentTestMixin
 from mayan.apps.rest_api.tests.base import BaseAPITestCase
 
 from ..permissions import (
-    permission_document_type_ocr_setup, permission_ocr_document,
-    permission_ocr_content_view
+    permission_document_type_ocr_setup, permission_document_version_ocr,
+    permission_document_version_ocr_content_view
 )
 
-from .literals import TEST_DOCUMENT_CONTENT
+from .literals import TEST_DOCUMENT_VERSION_OCR_CONTENT
 from .mixins import (
-    DocumentTypeOCRSettingsAPIViewTestMixin, OCRAPIViewTestMixin
+    DocumentTypeOCRSettingsAPIViewTestMixin, DocumentVersionOCRAPIViewTestMixin
 )
 
 
@@ -21,7 +21,7 @@ class DocumentTypeOCRSettingsAPIViewTestCase(
     auto_upload_test_document = False
 
     def test_document_type_ocr_settings_details_api_view_no_permission(self):
-        response = self._request_document_type_ocr_settings_details_api_view()
+        response = self._request_test_document_type_ocr_settings_details_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_document_type_ocr_settings_details_api_view_with_access(self):
@@ -30,12 +30,12 @@ class DocumentTypeOCRSettingsAPIViewTestCase(
             permission=permission_document_type_ocr_setup
         )
 
-        response = self._request_document_type_ocr_settings_details_api_view()
+        response = self._request_test_document_type_ocr_settings_details_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(response.data, {'auto_ocr': False})
 
     def test_document_type_ocr_settings_patch_api_view_no_permission(self):
-        response = self._request_document_type_ocr_settings_patch_api_view()
+        response = self._request_test_document_type_ocr_settings_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_document_type_ocr_settings_patch_api_view_with_access(self):
@@ -44,12 +44,12 @@ class DocumentTypeOCRSettingsAPIViewTestCase(
             permission=permission_document_type_ocr_setup
         )
 
-        response = self._request_document_type_ocr_settings_patch_api_view()
+        response = self._request_test_document_type_ocr_settings_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(response.data, {'auto_ocr': True})
 
     def test_document_type_ocr_settings_put_api_view_no_permission(self):
-        response = self._request_document_type_ocr_settings_put_api_view()
+        response = self._request_test_document_type_ocr_settings_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_document_type_ocr_settings_put_api_view_with_access(self):
@@ -58,16 +58,16 @@ class DocumentTypeOCRSettingsAPIViewTestCase(
             permission=permission_document_type_ocr_setup
         )
 
-        response = self._request_document_type_ocr_settings_put_api_view()
+        response = self._request_test_document_type_ocr_settings_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(response.data, {'auto_ocr': True})
 
 
-class OCRAPIViewTestCase(
-    DocumentTestMixin, OCRAPIViewTestMixin, BaseAPITestCase
+class DocumentVersionOCRAPIViewTestCase(
+    DocumentTestMixin, DocumentVersionOCRAPIViewTestMixin, BaseAPITestCase
 ):
     def test_submit_document_api_view_no_permission(self):
-        response = self._request_document_ocr_submit_view()
+        response = self._request_test_document_ocr_submit_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertFalse(
@@ -76,9 +76,10 @@ class OCRAPIViewTestCase(
 
     def test_submit_document_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_ocr_document
+            obj=self.test_document,
+            permission=permission_document_version_ocr
         )
-        response = self._request_document_ocr_submit_view()
+        response = self._request_test_document_ocr_submit_api_view()
         self.assertEqual(response.status_code, status.HTTP_202_ACCEPTED)
 
         self.assertTrue(
@@ -86,7 +87,7 @@ class OCRAPIViewTestCase(
         )
 
     def test_submit_document_version_api_view_no_permission(self):
-        response = self._request_document_version_ocr_submit_view()
+        response = self._request_test_document_version_ocr_submit_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertFalse(
@@ -95,9 +96,10 @@ class OCRAPIViewTestCase(
 
     def test_submit_document_version_api_view_with_access(self):
         self.grant_access(
-            permission=permission_ocr_document, obj=self.test_document
+            obj=self.test_document,
+            permission=permission_document_version_ocr
         )
-        response = self._request_document_version_ocr_submit_view()
+        response = self._request_test_document_version_ocr_submit_api_view()
         self.assertEqual(response.status_code, status.HTTP_202_ACCEPTED)
 
         self.assertTrue(
@@ -105,16 +107,17 @@ class OCRAPIViewTestCase(
         )
 
     def test_get_document_version_page_content_api_view_no_permission(self):
-        response = self._request_document_page_content_view()
+        response = self._request_test_document_version_page_ocr_content_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_get_document_version_page_content_api_view_with_access(self):
         self.test_document.submit_for_ocr()
         self.grant_access(
-            permission=permission_ocr_content_view, obj=self.test_document
+            obj=self.test_document,
+            permission=permission_document_version_ocr_content_view
         )
-        response = self._request_document_page_content_view()
+        response = self._request_test_document_version_page_ocr_content_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertTrue(
-            TEST_DOCUMENT_CONTENT in response.data['content']
+            TEST_DOCUMENT_VERSION_OCR_CONTENT in response.data['content']
         )
