@@ -20,8 +20,8 @@ from .permissions import (
 
 
 class GroupRolesView(AddRemoveView):
-    main_object_method_add = 'roles_add'
-    main_object_method_remove = 'roles_remove'
+    main_object_method_add_name = 'roles_add'
+    main_object_method_remove_name = 'roles_remove'
     main_object_model = Group
     main_object_permission = permission_group_edit
     main_object_pk_url_kwarg = 'group_id'
@@ -32,7 +32,7 @@ class GroupRolesView(AddRemoveView):
     related_field = 'roles'
 
     def get_actions_extra_kwargs(self):
-        return {'_user': self.request.user}
+        return {'_event_actor': self.request.user}
 
     def get_extra_context(self):
         return {
@@ -50,8 +50,8 @@ class RoleCreateView(SingleObjectCreateView):
     def get_extra_context(self):
         return {'title': _('Create new role')}
 
-    def get_save_extra_data(self):
-        return {'_user': self.request.user}
+    def get_instance_extra_data(self):
+        return {'_event_actor': self.request.user}
 
 
 class RoleDeleteView(SingleObjectDeleteView):
@@ -67,13 +67,13 @@ class RoleEditView(SingleObjectEditView):
     object_permission = permission_role_edit
     pk_url_kwarg = 'role_id'
 
-    def get_save_extra_data(self):
-        return {'_user': self.request.user}
+    def get_instance_extra_data(self):
+        return {'_event_actor': self.request.user}
 
 
 class SetupRoleMembersView(AddRemoveView):
-    main_object_method_add = 'groups_add'
-    main_object_method_remove = 'groups_remove'
+    main_object_method_add_name = 'groups_add'
+    main_object_method_remove_name = 'groups_remove'
     main_object_model = Role
     main_object_permission = permission_role_edit
     main_object_pk_url_kwarg = 'role_id'
@@ -84,7 +84,7 @@ class SetupRoleMembersView(AddRemoveView):
     related_field = 'groups'
 
     def get_actions_extra_kwargs(self):
-        return {'_user': self.request.user}
+        return {'_event_actor': self.request.user}
 
     def get_extra_context(self):
         return {
@@ -99,8 +99,8 @@ class SetupRoleMembersView(AddRemoveView):
 
 class SetupRolePermissionsView(AddRemoveView):
     grouped = True
-    main_object_method_add = 'permissions_add'
-    main_object_method_remove = 'permissions_remove'
+    main_object_method_add_name = 'permissions_add'
+    main_object_method_remove_name = 'permissions_remove'
     main_object_model = Role
     main_object_permission = permission_role_edit
     main_object_pk_url_kwarg = 'role_id'
@@ -127,14 +127,14 @@ class SetupRolePermissionsView(AddRemoveView):
             namespaces_dictionary[
                 permission.volatile_permission.namespace.label
             ].append(
-                (permission.pk, force_text(permission))
+                (permission.pk, force_text(s=permission))
             )
 
         # Sort permissions by their translatable namespace label
         return sorted(namespaces_dictionary.items())
 
     def get_actions_extra_kwargs(self):
-        return {'_user': self.request.user}
+        return {'_event_actor': self.request.user}
 
     def get_extra_context(self):
         return {
