@@ -1,18 +1,22 @@
 import json
 import logging
 
-from django.db import models, transaction
+from django.db import models
 from django.utils.encoding import force_text
 from django.utils.module_loading import import_string
 from django.utils.translation import ugettext_lazy as _
 
+from mayan.apps.databases.model_mixins import ExtraDataModelMixin
+from mayan.apps.events.classes import EventManagerSave
+from mayan.apps.events.decorators import method_event
+
 from .classes import NullBackend
 from .events import event_quota_created, event_quota_edited
 
 logger = logging.getLogger(__name__)
 
 
-class Quota(models.Model):
+class Quota(ExtraDataModelMixin, models.Model):
     backend_path = models.CharField(
         max_length=255,
         help_text=_('The dotted Python path to the backend class.'),
@@ -32,22 +36,21 @@ class Quota(models.Model):
         verbose_name_plural = _('Quotas')
 
     def __str__(self):
-        return force_text(self.backend_label())
+        return force_text(s=self.backend_label())
 
+    @method_event(
+        event_manager_class=EventManagerSave,
+        created={
+            'event': event_quota_created,
+            'target': 'self',
+        },
+        edited={
+            'event': event_quota_edited,
+            'target': 'self',
+        }
+    )
     def save(self, *args, **kwargs):
-        _user = kwargs.pop('_user', None)
-
-        with transaction.atomic():
-            is_new = not self.pk
-            super(Quota, self).save(*args, **kwargs)
-            if is_new:
-                event_quota_created.commit(
-                    actor=_user, target=self
-                )
-            else:
-                event_quota_edited.commit(
-                    actor=_user, target=self
-                )
+        super().save(*args, **kwargs)
 
     def backend_label(self):
         return self.get_backend_instance().label
@@ -81,7 +84,7 @@ class Quota(models.Model):
         try:
             return self.get_backend_class()(**self.loads())
         except Exception as exception:
-            logger.error(exception)
+            logger.error(exception, exc_info=True)
 
             return NullBackend()
 
