@@ -10,8 +10,8 @@ from django.utils.translation import ugettext_lazy as _
 from actstream.models import Action
 
 from mayan.apps.common.signals import signal_mayan_pre_save
-from mayan.apps.documents.events import event_document_create
-from mayan.apps.documents.models import Document, DocumentVersion
+from mayan.apps.documents.events import event_document_created
+from mayan.apps.documents.models import Document, DocumentFile
 from mayan.apps.user_management.querysets import get_user_queryset
 
 from .classes import QuotaBackend
@@ -35,7 +35,7 @@ def hook_factory_document_check_quota(klass):
     return hook_check_quota
 
 
-def hook_factory_document_version_check_quota(klass):
+def hook_factory_document_file_check_quota(klass):
     def hook_check_quota(**kwargs):
         # Pass the real parent document or create a fake one
         if 'document' in kwargs['kwargs']:
@@ -44,21 +44,23 @@ def hook_factory_document_version_check_quota(klass):
             document = types.SimpleNamespace(
                 document_type=kwargs['kwargs']['document_type']
             )
-        # Fake DocumentVersion to be able to reuse the
+        # Fake DocumentFile to be able to reuse the
         # .process() method for pre check.
-        fake_document_instance = types.SimpleNamespace(
-            file=kwargs['kwargs']['shared_uploaded_file'].file,
-            document=document,
-            pk=None
-        )
+        shared_uploaded_file = kwargs['kwargs']['shared_uploaded_file']
+        if shared_uploaded_file:
+            fake_document_instance = types.SimpleNamespace(
+                file=kwargs['kwargs']['shared_uploaded_file'].file,
+                document=document,
+                pk=None
+            )
 
-        final_kwargs = kwargs['kwargs'].copy()
-        final_kwargs['instance'] = fake_document_instance
+            final_kwargs = kwargs['kwargs'].copy()
+            final_kwargs['instance'] = fake_document_instance
 
-        for quota in klass.get_instances().filter(enabled=True):
-            backend_instance = quota.get_backend_instance()
+            for quota in klass.get_instances().filter(enabled=True):
+                backend_instance = quota.get_backend_instance()
 
-            backend_instance.process(**final_kwargs)
+                backend_instance.process(**final_kwargs)
     return hook_check_quota
 
 
@@ -112,7 +114,7 @@ class DocumentCountQuota(
             ),
         )
         action_filter_kwargs = {
-            'verb': event_document_create.id
+            'verb': event_document_created.id
         }
         document_filter_kwargs = {}
 
@@ -181,13 +183,13 @@ class DocumentSizeQuota(
         }
     }
     label = _('Document size limit')
-    sender = DocumentVersion
+    sender = DocumentFile
     signal = signal_mayan_pre_save
 
     @classmethod
     def _initialize(cls):
-        DocumentVersion.register_pre_create_hook(
-            func=hook_factory_document_version_check_quota(klass=cls)
+        DocumentFile.register_pre_create_hook(
+            func=hook_factory_document_file_check_quota(klass=cls)
         )
 
     def __init__(
