@@ -1,7 +1,6 @@
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.converter.classes import Layer
-from mayan.apps.converter.layers import layer_saved_transformations
 
 from .permissions import (
     permission_redaction_create, permission_redaction_delete,
@@ -14,7 +13,7 @@ layer_redactions = Layer(
         'Redactions allow removing access to confidential and '
         'sensitive information without having to modify the document.'
     ), label=_('Redactions'), name='redactions',
-    order=layer_saved_transformations.order - 1, permissions={
+    order=0, permissions={
         'create': permission_redaction_create,
         'delete': permission_redaction_delete,
         'exclude': permission_redaction_exclude,
