@@ -87,7 +87,7 @@ class SettingNamespace(AppsModuleLoaderMixin):
         self._settings = []
 
     def __str__(self):
-        return force_text(self.label)
+        return force_text(s=self.label)
 
     def add_setting(self, **kwargs):
         return Setting(namespace=self, **kwargs)
@@ -182,7 +182,7 @@ class Setting:
         if isinstance(value, (list, tuple)):
             return [Setting.express_promises(item) for item in value]
         elif isinstance(value, Promise):
-            return force_text(value)
+            return force_text(s=value)
         else:
             return value
 
@@ -194,7 +194,7 @@ class Setting:
         )
         # safe_dump returns bytestrings
         # Disregard the last 3 dots that mark the end of the YAML document
-        if force_text(result).endswith('...\n'):
+        if force_text(s=result).endswith('...\n'):
             result = result[:-4]
 
         return result
@@ -250,7 +250,7 @@ class Setting:
     @classmethod
     def get_hash(cls):
         return force_text(
-            hashlib.sha256(force_bytes(cls.dump_data())).hexdigest()
+            s=hashlib.sha256(force_bytes(s=cls.dump_data())).hexdigest()
         )
 
     @classmethod
@@ -292,10 +292,12 @@ class Setting:
         self.__class__._registry[global_name] = self
 
     def __str__(self):
-        return force_text(self.global_name)
+        return force_text(s=self.global_name)
 
-    def cache_value(self):
-        environment_value = os.environ.get('MAYAN_{}'.format(self.global_name))
+    def cache_value(self, global_name=None, default_override=None):
+        global_name = global_name or self.global_name
+
+        environment_value = os.environ.get('MAYAN_{}'.format(global_name))
         if environment_value:
             self.environment_variable = True
             try:
@@ -304,22 +306,25 @@ class Setting:
                 raise type(exception)(
                     'Error interpreting environment variable: {} with '
                     'value: {}; {}'.format(
-                        self.global_name, environment_value, exception
+                        global_name, environment_value, exception
                     )
                 )
         else:
             try:
                 # Try the config file
-                self.raw_value = self.get_config_file_content()[self.global_name]
+                self.raw_value = self.get_config_file_content()[global_name]
             except KeyError:
                 try:
                     # Try the Django settings variable
                     self.raw_value = getattr(
-                        settings, self.global_name
+                        settings, global_name
                     )
                 except AttributeError:
                     # Finally set to the default value
-                    self.raw_value = self.default
+                    if default_override:
+                        self.raw_value = default_override
+                    else:
+                        self.raw_value = self.default
             else:
                 # Found in the config file, try to migrate the value
                 self.migrate()
@@ -354,6 +359,7 @@ class Setting:
 
     def set(self, value):
         self.value = Setting.serialize_value(value=value)
+        self.loaded = True
 
     @property
     def value(self):
