@@ -4,10 +4,12 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.common.apps import MayanAppConfig
 from mayan.apps.common.classes import MissingItem
-from mayan.apps.common.signals import signal_post_initial_setup, signal_post_upgrade
+from mayan.apps.common.signals import (
+    signal_post_initial_setup, signal_post_upgrade
+)
 from mayan.apps.converter.links import link_transformation_list
 from mayan.apps.documents.menus import menu_documents
-from mayan.apps.documents.signals import signal_post_version_upload
+from mayan.apps.documents.signals import signal_post_document_file_upload
 from mayan.apps.logging.classes import ErrorLog
 from mayan.apps.navigation.classes import SourceColumn
 from mayan.apps.views.html_widgets import TwoStateWidget
@@ -15,9 +17,9 @@ from mayan.apps.common.menus import (
     menu_list_facet, menu_object, menu_secondary, menu_setup
 )
 
-from .classes import StagingFile
+from .classes import DocumentCreateWizardStep, StagingFile
 from .handlers import (
-    handler_copy_transformations_to_version,
+    handler_copy_transformations_to_file,
     handler_create_default_document_source,
     handler_delete_interval_source_periodic_task,
     handler_initialize_periodic_tasks
@@ -29,7 +31,7 @@ from .links import (
     link_setup_source_create_watch_folder, link_setup_source_create_webform,
     link_setup_source_create_staging_folder, link_setup_source_delete,
     link_setup_source_edit, link_staging_file_delete,
-    link_document_version_upload
+    link_document_file_upload
 )
 from .widgets import StagingFileThumbnailWidget
 
@@ -48,7 +50,10 @@ class SourcesApp(MayanAppConfig):
     verbose_name = _('Sources')
 
     def ready(self):
-        super(SourcesApp, self).ready()
+        super().ready()
+
+        DocumentCreateWizardStep.load_modules()
+
         DocumentType = apps.get_model(
             app_label='documents', model_name='DocumentType'
         )
@@ -148,11 +153,10 @@ class SourcesApp(MayanAppConfig):
         )
         menu_setup.bind_links(links=(link_setup_sources,))
         menu_secondary.bind_links(
-            links=(link_document_version_upload,),
+            links=(link_document_file_upload,),
             sources=(
-                'documents:document_version_list',
-                'documents:document_version_revert',
-                'sources:document_version_upload'
+                'documents:document_file_list',
+                'sources:document_file_upload'
             )
         )
 
@@ -169,7 +173,7 @@ class SourcesApp(MayanAppConfig):
             receiver=handler_initialize_periodic_tasks,
             dispatch_uid='sources_handler_initialize_periodic_tasks'
         )
-        signal_post_version_upload.connect(
-            receiver=handler_copy_transformations_to_version,
-            dispatch_uid='sources_handler_copy_transformations_to_version'
+        signal_post_document_file_upload.connect(
+            receiver=handler_copy_transformations_to_file,
+            dispatch_uid='sources_handler_copy_transformations_to_file'
         )
