@@ -12,6 +12,7 @@ from django.urls import reverse
 from django.utils.encoding import force_text
 from django.utils.functional import cached_property
 
+from mayan.apps.common.class_mixins import AppsModuleLoaderMixin
 from mayan.apps.converter.classes import ConverterBase
 from mayan.apps.converter.transformations import TransformationResize
 from mayan.apps.storage.classes import DefinedStorage
@@ -21,6 +22,85 @@ from .literals import STORAGE_NAME_SOURCE_STAGING_FOLDER_FILE
 logger = logging.getLogger(name=__name__)
 
 
+class DocumentCreateWizardStep(AppsModuleLoaderMixin):
+    _deregistry = {}
+    _loader_module_name = 'wizard_steps'
+    _registry = {}
+
+    @classmethod
+    def deregister(cls, step):
+        cls._deregistry[step.name] = step
+
+    @classmethod
+    def deregister_all(cls):
+        for step in cls.get_all():
+            cls.deregister(step=step)
+
+    @classmethod
+    def done(cls, wizard):
+        return {}
+
+    @classmethod
+    def get(cls, name):
+        for step in cls.get_all():
+            if name == step.name:
+                return step
+
+    @classmethod
+    def get_all(cls):
+        return sorted(
+            [
+                step for step in cls._registry.values() if step.name not in cls._deregistry
+            ], key=lambda x: x.number
+        )
+
+    @classmethod
+    def get_choices(cls, attribute_name):
+        return [
+            (step.name, getattr(step, attribute_name)) for step in cls.get_all()
+        ]
+
+    @classmethod
+    def get_form_initial(cls, wizard):
+        return {}
+
+    @classmethod
+    def get_form_kwargs(cls, wizard):
+        return {}
+
+    @classmethod
+    def post_upload_process(cls, document, querystring=None):
+        for step in cls.get_all():
+            step.step_post_upload_process(
+                document=document, querystring=querystring
+            )
+
+    @classmethod
+    def register(cls, step):
+        if step.name in cls._registry:
+            raise Exception('A step with this name already exists: %s' % step.name)
+
+        if step.number in [reigstered_step.number for reigstered_step in cls.get_all()]:
+            raise Exception('A step with this number already exists: %s' % step.name)
+
+        cls._registry[step.name] = step
+
+    @classmethod
+    def reregister(cls, name):
+        cls._deregistry.pop(name)
+
+    @classmethod
+    def reregister_all(cls):
+        cls._deregistry = {}
+
+    @classmethod
+    def step_post_upload_process(cls, document, querystring=None):
+        """
+        Optional method executed when the wizard ends to allow the step to
+        perform its action.
+        """
+
+
 class PseudoFile(File):
     def __init__(self, file, name):
         self.name = name
@@ -56,7 +136,7 @@ class StagingFile:
             ))
 
     def __str__(self):
-        return force_text(self.filename)
+        return force_text(s=self.filename)
 
     def as_file(self):
         return File(
@@ -156,13 +236,13 @@ class StagingFile:
             if not self.storage.exists(cache_filename):
                 self.storage.save(name=cache_filename, content=ContentFile(content=''))
 
-            with self.storage.open(file=cache_filename, mode='wb+') as file_object:
+            with self.storage.open(name=cache_filename, mode='wb+') as file_object:
                 file_object.write(page_image.getvalue())
         except Exception as exception:
             # Cleanup in case of error
             logger.error(
                 'Error creating staging file cache "%s"; %s',
-                cache_filename, exception
+                cache_filename, exception, exc_info=True
             )
             self.storage.delete(cache_filename)
             if file_object:
