@@ -6,10 +6,7 @@ from mayan.apps.converter.layers import layer_saved_transformations
 from .literals import SOURCE_UNCOMPRESS_CHOICE_ASK
 
 
-def handler_copy_transformations_to_version(sender, instance, **kwargs):
-    # TODO: Fix this, source should be previous version
-    # TODO: Fix this, shouldn't this be at the documents app
-
+def handler_copy_transformations_to_file(sender, instance, **kwargs):
     layer_saved_transformations.copy_transformations(
         source=instance.document, targets=instance.pages.all()
     )
