@@ -1,7 +1,6 @@
 import json
 import logging
 
-from django.conf import settings
 from django.db import models, transaction
 from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _
@@ -10,14 +9,14 @@ from django_celery_beat.models import PeriodicTask, IntervalSchedule
 from model_utils.managers import InheritanceManager
 
 from mayan.apps.converter.layers import layer_saved_transformations
-from mayan.apps.documents.models import Document, DocumentType
+from mayan.apps.documents.models import DocumentType
 from mayan.apps.storage.compressed_files import Archive
 from mayan.apps.storage.exceptions import NoMIMETypeMatch
 
+from ..classes import DocumentCreateWizardStep
 from ..literals import (
     DEFAULT_INTERVAL, SOURCE_CHOICES, SOURCE_UNCOMPRESS_CHOICES
 )
-from ..wizards import WizardStep
 
 logger = logging.getLogger(name=__name__)
 
@@ -41,11 +40,12 @@ class Source(models.Model):
 
     @classmethod
     def class_fullname(cls):
-        return force_text(dict(SOURCE_CHOICES).get(cls.source_type))
+        return force_text(s=dict(SOURCE_CHOICES).get(cls.source_type))
 
     def clean_up_upload_file(self, upload_file_object):
-        pass
-        # TODO: Should raise NotImplementedError?
+        """
+        Optional method. Non fatal if not defined.
+        """
 
     def fullname(self):
         return ' '.join([self.class_fullname(), '"%s"' % self.label])
@@ -73,7 +73,7 @@ class Source(models.Model):
                 for compressed_file_child in compressed_file.members():
                     with compressed_file.open_member(filename=compressed_file_child) as file_object:
                         kwargs.update(
-                            {'label': force_text(compressed_file_child)}
+                            {'label': force_text(s=compressed_file_child)}
                         )
                         documents.append(
                             self.upload_document(
@@ -95,20 +95,23 @@ class Source(models.Model):
         return documents
 
     def get_upload_file_object(self, form_data):
-        pass
-        # TODO: Should raise NotImplementedError?
+        """
+        Optional method. Non fatal if not defined.
+        """
 
     def upload_document(
         self, file_object, document_type, description=None, label=None,
         language=None, querystring=None, user=None
     ):
         """
-        Upload an individual document
+        Upload an individual document.
         """
+        document = None
         try:
-            document = document_type.new_document(
-                description=description, file_object=file_object, label=label,
-                language=language, _user=user
+            document, document_file = document_type.new_document(
+                file_object=file_object, label=label,
+                description=description, language=language,
+                _user=user
             )
         except Exception as exception:
             logger.critical(
@@ -116,33 +119,20 @@ class Source(models.Model):
                 '"%s" from source "%s"; %s',
                 label or file_object.name, self, exception
             )
+            if document:
+                document.delete(to_trash=False)
             raise
         else:
-            try:
-                document_version = document.new_version(
-                    file_object=file_object, _user=user,
-                )
+            if user:
+                document.add_as_recent_document_for_user(user=user)
 
-                if user:
-                    document.add_as_recent_document_for_user(user=user)
-
-                layer_saved_transformations.copy_transformations(
-                    source=self, targets=document_version.pages.all()
-                )
-
-            except Exception as exception:
-                logger.critical(
-                    'Unexpected exception while trying to create version for '
-                    'new document "%s" from source "%s"; %s',
-                    label or file_object.name, self, exception, exc_info=True
-                )
-                document.delete(to_trash=False)
-                raise
-            else:
-                WizardStep.post_upload_process(
-                    document=document, querystring=querystring
-                )
-                return document
+            layer_saved_transformations.copy_transformations(
+                source=self, targets=document_file.pages.all()
+            )
+            DocumentCreateWizardStep.post_upload_process(
+                document=document, querystring=querystring
+            )
+            return document
 
 
 class InteractiveSource(Source):
@@ -195,8 +185,8 @@ class IntervalBaseModel(OutOfProcessSource):
 
             interval_instance = periodic_task.interval
 
-            if tuple(interval_instance.periodictask_set.values_list('id', flat=True)) == (periodic_task.pk,):
-                # Only delete the interval if nobody else is using it
+            if interval_instance.periodictask_set.count() == 1:
+                # Only delete the interval if nobody else is using it.
                 interval_instance.delete()
             else:
                 periodic_task.delete()
@@ -218,21 +208,20 @@ class IntervalBaseModel(OutOfProcessSource):
                     exception.__class__.__name__, exception
                 )
             )
-            if settings.DEBUG:
-                raise
+            raise
         else:
             self.error_log.all().delete()
 
     def delete(self, *args, **kwargs):
         pk = self.pk
         with transaction.atomic():
-            super(IntervalBaseModel, self).delete(*args, **kwargs)
+            super().delete(*args, **kwargs)
             self._delete_periodic_task(pk=pk)
 
     def save(self, *args, **kwargs):
         new_source = not self.pk
         with transaction.atomic():
-            super(IntervalBaseModel, self).save(*args, **kwargs)
+            super().save(*args, **kwargs)
 
             if not new_source:
                 self._delete_periodic_task()
@@ -240,7 +229,7 @@ class IntervalBaseModel(OutOfProcessSource):
             interval_instance, created = IntervalSchedule.objects.get_or_create(
                 every=self.interval, period='seconds'
             )
-            # Create a new interval or reuse someone else's
+            # Create a new interval or reuse someone else's.
             PeriodicTask.objects.create(
                 name=self._get_periodic_task_name(),
                 interval=interval_instance,
