@@ -1,6 +1,6 @@
 from django.utils.encoding import force_bytes, force_text
 
-from .literals import TEST_EMAIL_BASE64_FILENAME
+from .literals import TEST_EMAIL_BASE64_FILENAME, TEST_STAGING_PREVIEW_WIDTH
 
 
 class MockIMAPMessage:
@@ -76,7 +76,7 @@ class MockIMAPServer:
                 flag_modified.append(message)
 
             message_number = message.get_number()
-            message_numbers.append(force_text(message_number))
+            message_numbers.append(force_text(s=message_number))
             uid = message.uid
             uids.append(uid)
             body = TEST_EMAIL_BASE64_FILENAME
@@ -107,9 +107,7 @@ class MockIMAPServer:
         for message in self.mailbox_selected.get_messages():
             if '\\Deleted' in message.flags:
                 result.append(
-                    force_text(
-                        message.get_number()
-                    )
+                    force_text(s=message.get_number())
                 )
                 message.delete()
 
@@ -151,7 +149,7 @@ class MockIMAPServer:
 
         message_sequences = []
         for message in results:
-            message_sequences.append(force_text(message.get_number()))
+            message_sequences.append(force_text(s=message.get_number()))
 
         return ('OK', ' '.join(message_sequences))
 
@@ -227,7 +225,7 @@ class MockPOP3Mailbox:
 
     def getwelcome(self):
         return force_bytes(
-            '+OK server ready for requests from 127.0.0.0 xxxxxxxxxxxxxxxxx'
+            s='+OK server ready for requests from 127.0.0.0 xxxxxxxxxxxxxxxxx'
         )
 
     def list(self, which=None):
@@ -252,7 +250,7 @@ class MockPOP3Mailbox:
 
             messages_total_size = messages_total_size + message_size
             message_list.append(
-                force_bytes('{} {}'.format(message_number, message_size))
+                force_bytes(s='{} {}'.format(message_number, message_size))
             )
 
             message_number = message_number + 1
@@ -264,17 +262,17 @@ class MockPOP3Mailbox:
 
         return (
             force_bytes(
-                '+OK {} messages ({} bytes)'.format(
+                s='+OK {} messages ({} bytes)'.format(
                     len(self.messages), messages_total_size
                 )
             ), message_list, result_size
         )
 
     def user(self, user):
-        return force_bytes('+OK send PASS')
+        return force_bytes(s='+OK send PASS')
 
     def pass_(self, pswd):
-        return force_bytes('+OK Welcome.')
+        return force_bytes(s='+OK Welcome.')
 
     def quit(self):
         return
@@ -285,3 +283,6 @@ class MockPOP3Mailbox:
 
 class MockStagingFolder:
     """Mock of a StagingFolder model"""
+    pk = 1
+    preview_height = None
+    preview_width = TEST_STAGING_PREVIEW_WIDTH
