@@ -8,10 +8,11 @@ import mock
 from django.core import mail
 from django.utils.encoding import force_bytes, force_text
 
-from django_celery_beat.models import PeriodicTask
+from django_celery_beat.models import IntervalSchedule, PeriodicTask
 
 from mayan.apps.common.serialization import yaml_dump
 from mayan.apps.documents.models import Document
+from mayan.apps.documents.storages import storage_document_files
 from mayan.apps.documents.tests.base import GenericDocumentTestCase
 from mayan.apps.documents.tests.literals import (
     TEST_COMPRESSED_DOCUMENT_PATH, TEST_NON_ASCII_DOCUMENT_FILENAME,
@@ -19,7 +20,6 @@ from mayan.apps.documents.tests.literals import (
     TEST_SMALL_DOCUMENT_FILENAME, TEST_SMALL_DOCUMENT_PATH
 )
 from mayan.apps.metadata.models import MetadataType
-from mayan.apps.storage.utils import mkdtemp
 
 from ..literals import SOURCE_UNCOMPRESS_CHOICE_Y
 from ..models.email_sources import EmailBaseModel, IMAPEmail, POP3Email
@@ -93,7 +93,7 @@ class EmailBaseTestCase(GenericDocumentTestCase):
             source=self.source, message_text=TEST_EMAIL_NO_CONTENT_TYPE
         )
         self.assertTrue(
-            TEST_EMAIL_NO_CONTENT_TYPE_STRING in Document.objects.first().open().read()
+            TEST_EMAIL_NO_CONTENT_TYPE_STRING in Document.objects.first().file_latest.open().read()
         )
 
     def test_decode_email_zero_length_attachment(self):
@@ -281,48 +281,44 @@ class IMAPSourceTestCase(GenericDocumentTestCase):
 class IntervalSourceTestCase(WatchFolderTestMixin, GenericDocumentTestCase):
     auto_upload_test_document = False
 
-    def setUp(self):
-        super(IntervalSourceTestCase, self).setUp()
-        self.temporary_directory = mkdtemp()
-
-    def tearDown(self):
-        shutil.rmtree(self.temporary_directory)
-        super(IntervalSourceTestCase, self).tearDown()
-
     def test_periodic_task_create(self):
         periodic_task_count = PeriodicTask.objects.count()
 
         self._create_test_watchfolder()
-        self.assertTrue(PeriodicTask.objects.count() > periodic_task_count)
+        self.assertEqual(
+            PeriodicTask.objects.count(), periodic_task_count + 1
+        )
 
     def test_periodic_task_delete(self):
         self._create_test_watchfolder()
         periodic_task_count = PeriodicTask.objects.count()
 
         self.test_document_type.delete()
-        self.assertTrue(PeriodicTask.objects.count() < periodic_task_count)
-
-
-class SANESourceTestCase(GenericDocumentTestCase):
-    auto_upload_test_document = False
-
-    def _create_test_scanner_source(self):
-        self.test_source = SaneScanner.objects.create(
-            label='', device_name='test'
+        self.assertEqual(
+            PeriodicTask.objects.count(), periodic_task_count - 1
         )
 
-    def test_command(self):
-        self._create_test_scanner_source()
-        file_object = self.test_source.execute_command(arguments=('-V',))
-        self.assertTrue(force_bytes('sane') in file_object.read())
+    def test_interval_schedule_preseve(self):
+        internal_schedule_count = IntervalSchedule.objects.count()
 
-    def test_scan(self):
-        self._create_test_scanner_source()
+        self._create_test_watchfolder(label='test source 1')
+        self._create_test_watchfolder(label='test source 2')
 
-        file_object = self.test_source.get_upload_file_object(
-            form_data={'document_type': self.test_document_type.pk}
+        self.assertEqual(
+            IntervalSchedule.objects.count(), internal_schedule_count + 1
+        )
+
+        self.test_watch_folders[1].delete()
+
+        self.assertEqual(
+            IntervalSchedule.objects.count(), internal_schedule_count + 1
+        )
+
+        self.test_watch_folders[0].delete()
+
+        self.assertEqual(
+            IntervalSchedule.objects.count(), internal_schedule_count
         )
-        self.assertTrue(file_object.size > 0)
 
 
 class POP3SourceTestCase(GenericDocumentTestCase):
@@ -342,16 +338,30 @@ class POP3SourceTestCase(GenericDocumentTestCase):
         )
 
 
-class WatchFolderTestCase(WatchFolderTestMixin, GenericDocumentTestCase):
+class SANESourceTestCase(GenericDocumentTestCase):
     auto_upload_test_document = False
 
-    def setUp(self):
-        super(WatchFolderTestCase, self).setUp()
-        self.temporary_directory = mkdtemp()
+    def _create_test_scanner_source(self):
+        self.test_source = SaneScanner.objects.create(
+            label='', device_name='test'
+        )
 
-    def tearDown(self):
-        shutil.rmtree(self.temporary_directory)
-        super(WatchFolderTestCase, self).tearDown()
+    def test_command(self):
+        self._create_test_scanner_source()
+        file_object = self.test_source.execute_command(arguments=('-V',))
+        self.assertTrue(force_bytes(s='sane') in file_object.read())
+
+    def test_scan(self):
+        self._create_test_scanner_source()
+
+        file_object = self.test_source.get_upload_file_object(
+            form_data={'document_type': self.test_document_type.pk}
+        )
+        self.assertTrue(file_object.size > 0)
+
+
+class WatchFolderTestCase(WatchFolderTestMixin, GenericDocumentTestCase):
+    auto_upload_test_document = False
 
     def test_subfolder_support_disabled(self):
         self._create_test_watchfolder()
@@ -360,7 +370,9 @@ class WatchFolderTestCase(WatchFolderTestMixin, GenericDocumentTestCase):
         test_subfolder = test_path.joinpath(TEST_WATCHFOLDER_SUBFOLDER)
         test_subfolder.mkdir()
 
-        shutil.copy(TEST_SMALL_DOCUMENT_PATH, force_text(test_subfolder))
+        shutil.copy(
+            src=TEST_SMALL_DOCUMENT_PATH, dst=force_text(s=test_subfolder)
+        )
         self.test_watch_folder.check_source()
         self.assertEqual(Document.objects.count(), 0)
 
@@ -373,19 +385,21 @@ class WatchFolderTestCase(WatchFolderTestMixin, GenericDocumentTestCase):
         test_subfolder = test_path.joinpath(TEST_WATCHFOLDER_SUBFOLDER)
         test_subfolder.mkdir()
 
-        shutil.copy(TEST_SMALL_DOCUMENT_PATH, force_text(test_subfolder))
+        shutil.copy(
+            src=TEST_SMALL_DOCUMENT_PATH, dst=force_text(s=test_subfolder)
+        )
         self.test_watch_folder.check_source()
         self.assertEqual(Document.objects.count(), 1)
 
         document = Document.objects.first()
 
-        self.assertEqual(document.exists(), True)
-        self.assertEqual(document.size, 17436)
+        self.assertEqual(document.file_latest.exists(), True)
+        self.assertEqual(document.file_latest.size, 17436)
 
-        self.assertEqual(document.file_mimetype, 'image/png')
-        self.assertEqual(document.file_mime_encoding, 'binary')
+        self.assertEqual(document.file_latest.mimetype, 'image/png')
+        self.assertEqual(document.file_latest.encoding, 'binary')
         self.assertEqual(document.label, TEST_SMALL_DOCUMENT_FILENAME)
-        self.assertEqual(document.page_count, 1)
+        self.assertEqual(document.file_latest.pages.count(), 1)
 
     def test_issue_gh_163(self):
         """
@@ -394,19 +408,21 @@ class WatchFolderTestCase(WatchFolderTestMixin, GenericDocumentTestCase):
         """
         self._create_test_watchfolder()
 
-        shutil.copy(TEST_NON_ASCII_DOCUMENT_PATH, self.temporary_directory)
+        shutil.copy(
+            src=TEST_NON_ASCII_DOCUMENT_PATH, dst=self.temporary_directory
+        )
         self.test_watch_folder.check_source()
         self.assertEqual(Document.objects.count(), 1)
 
         document = Document.objects.first()
 
-        self.assertEqual(document.exists(), True)
-        self.assertEqual(document.size, 17436)
+        self.assertEqual(document.file_latest.exists(), True)
+        self.assertEqual(document.file_latest.size, 17436)
 
-        self.assertEqual(document.file_mimetype, 'image/png')
-        self.assertEqual(document.file_mime_encoding, 'binary')
+        self.assertEqual(document.file_latest.mimetype, 'image/png')
+        self.assertEqual(document.file_latest.encoding, 'binary')
         self.assertEqual(document.label, TEST_NON_ASCII_DOCUMENT_FILENAME)
-        self.assertEqual(document.page_count, 1)
+        self.assertEqual(document.file_latest.pages.count(), 1)
 
     def test_issue_gh_163_expanded(self):
         """
@@ -415,26 +431,26 @@ class WatchFolderTestCase(WatchFolderTestMixin, GenericDocumentTestCase):
         self._create_test_watchfolder()
 
         shutil.copy(
-            TEST_NON_ASCII_COMPRESSED_DOCUMENT_PATH, self.temporary_directory
+            src=TEST_NON_ASCII_COMPRESSED_DOCUMENT_PATH,
+            dst=self.temporary_directory
         )
         self.test_watch_folder.check_source()
         self.assertEqual(Document.objects.count(), 1)
 
         document = Document.objects.first()
 
-        self.assertEqual(document.exists(), True)
-        self.assertEqual(document.size, 17436)
-
-        self.assertEqual(document.file_mimetype, 'image/png')
-        self.assertEqual(document.file_mime_encoding, 'binary')
+        self.assertEqual(document.file_latest.exists(), True)
+        self.assertEqual(document.file_latest.size, 17436)
+        self.assertEqual(document.file_latest.mimetype, 'image/png')
+        self.assertEqual(document.file_latest.encoding, 'binary')
         self.assertEqual(document.label, TEST_NON_ASCII_DOCUMENT_FILENAME)
-        self.assertEqual(document.page_count, 1)
+        self.assertEqual(document.file_latest.pages.count(), 1)
 
     def test_locking_support(self):
         self._create_test_watchfolder()
 
         shutil.copy(
-            TEST_SMALL_DOCUMENT_PATH, self.temporary_directory
+            src=TEST_SMALL_DOCUMENT_PATH, dst=self.temporary_directory
         )
 
         path_test_file = Path(
@@ -448,3 +464,30 @@ class WatchFolderTestCase(WatchFolderTestMixin, GenericDocumentTestCase):
             process.join()
 
             self.assertEqual(Document.objects.count(), 0)
+
+
+class SourceModelTestCase(SourceTestMixin, GenericDocumentTestCase):
+    auto_upload_test_document = False
+
+    def setUp(self):
+        super().setUp()
+        self.storage_document_files_instance = storage_document_files.get_storage_instance()
+
+    def _get_storage_document_files_count(self):
+        return len(
+            self.storage_document_files_instance.listdir(path='')[1]
+        )
+
+    def test_single_storage_file_creation(self):
+        document_file_count = self._get_storage_document_files_count()
+
+        with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+            self.test_source.handle_upload(
+                file_object=file_object,
+                document_type=self.test_document_type
+            )
+
+        self.assertEqual(
+            self._get_storage_document_files_count(),
+            document_file_count + 1
+        )
