@@ -15,12 +15,12 @@ from .literals import TEST_CONTENT, TEST_FILE_NAME
 
 class EncryptedPassthroughStorageTestCase(BaseTestCase):
     def setUp(self):
-        super(EncryptedPassthroughStorageTestCase, self).setUp()
+        super().setUp()
         self.temporary_directory = mkdtemp()
 
     def tearDown(self):
         fs_cleanup(filename=self.temporary_directory)
-        super(EncryptedPassthroughStorageTestCase, self).tearDown()
+        super().tearDown()
 
     def test_file_save_and_load(self):
         storage = EncryptedPassthroughStorage(
@@ -32,7 +32,7 @@ class EncryptedPassthroughStorageTestCase(BaseTestCase):
 
         test_file_name = storage.save(
             name=TEST_FILE_NAME, content=ContentFile(
-                content=force_bytes(TEST_CONTENT)
+                content=force_bytes(s=TEST_CONTENT)
             )
         )
 
@@ -56,12 +56,12 @@ class EncryptedPassthroughStorageTestCase(BaseTestCase):
 
 class ZipCompressedPassthroughStorageTestCase(BaseTestCase):
     def setUp(self):
-        super(ZipCompressedPassthroughStorageTestCase, self).setUp()
+        super().setUp()
         self.temporary_directory = mkdtemp()
 
     def tearDown(self):
         fs_cleanup(filename=self.temporary_directory)
-        super(ZipCompressedPassthroughStorageTestCase, self).tearDown()
+        super().tearDown()
 
     def test_file_save_and_load(self):
         storage = ZipCompressedPassthroughStorage(
@@ -84,8 +84,48 @@ class ZipCompressedPassthroughStorageTestCase(BaseTestCase):
 
         with path_file.open(mode='rb') as file_object:
             self.assertNotEqual(
-                file_object.read(), force_bytes(TEST_CONTENT)
+                file_object.read(), force_bytes(s=TEST_CONTENT)
             )
 
         with storage.open(name=TEST_FILE_NAME, mode='r') as file_object:
             self.assertEqual(file_object.read(), TEST_CONTENT)
+
+
+class CombinationPassthroughStorageTestCase(BaseTestCase):
+    def setUp(self):
+        super().setUp()
+        self.temporary_directory = mkdtemp()
+
+    def tearDown(self):
+        fs_cleanup(filename=self.temporary_directory)
+        super().tearDown()
+
+    def test_file_save_and_load(self):
+        storage = EncryptedPassthroughStorage(
+            password='testpassword',
+            next_storage_backend='mayan.apps.storage.backends.compressedstorage.ZipCompressedPassthroughStorage',
+            next_storage_backend_arguments={
+                'next_storage_backend_arguments': {
+                    'location': self.temporary_directory,
+                }
+            }
+        )
+
+        test_file_name = storage.save(
+            name=TEST_FILE_NAME, content=ContentFile(content=TEST_CONTENT)
+        )
+
+        path_file = Path(self.temporary_directory) / test_file_name
+
+        with path_file.open(mode='rb') as file_object:
+            self.assertEqual(
+                get_mimetype(file_object=file_object),
+                ('application/zip', 'binary')
+            )
+
+        with path_file.open(mode='rb') as file_object:
+            self.assertNotEqual(
+                file_object.read(), force_bytes(s=TEST_CONTENT)
+            )
+        with storage.open(name=TEST_FILE_NAME, mode='r') as file_object:
+            self.assertEqual(file_object.read(), TEST_CONTENT)
