@@ -1,10 +1,9 @@
 import logging
 
-from django.contrib import messages
 from django.shortcuts import reverse
 from django.template import RequestContext
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _, ungettext
+from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.acls.models import AccessControlList
 from mayan.apps.common.classes import ModelQueryFields
@@ -14,12 +13,12 @@ from mayan.apps.views.generics import (
     MultipleObjectFormActionView, MultipleObjectConfirmActionView,
     SingleObjectCreateView, SingleObjectEditView, SingleObjectListView
 )
-from mayan.apps.views.mixins import ExternalObjectMixin
+from mayan.apps.views.mixins import ExternalObjectViewMixin
 
 from .forms import TagMultipleSelectionForm
 from .icons import icon_menu_tags, icon_document_tag_remove_submit
 from .links import link_document_tag_multiple_attach, link_tag_create
-from .models import Tag
+from .models import DocumentTag, Tag
 from .permissions import (
     permission_tag_attach, permission_tag_create, permission_tag_delete,
     permission_tag_edit, permission_tag_remove, permission_tag_view
@@ -30,99 +29,74 @@ logger = logging.getLogger(name=__name__)
 
 class TagAttachActionView(MultipleObjectFormActionView):
     form_class = TagMultipleSelectionForm
-    model = Document
     object_permission = permission_tag_attach
     pk_url_kwarg = 'document_id'
-    success_message = _('Tag attach request performed on %(count)d document')
-    success_message_plural = _(
-        'Tag attach request performed on %(count)d documents'
+    source_queryset = Document.valid
+    success_message_single = _(
+        'Tags attached to document "%(object)s" successfully.'
     )
+    success_message_singular = _(
+        'Tags attached to %(count)d document successfully.'
+    )
+    success_message_plural = _(
+        'Tags attached to %(count)d documents successfully.'
+    )
+    title_single = _('Attach tags to document: %(object)s')
+    title_singular = _('Attach tags to %(count)d document.')
+    title_plural = _('Attach tags to %(count)d documents.')
 
     def get_extra_context(self):
-        queryset = self.object_list
-
-        result = {
+        context = {
             'submit_label': _('Attach'),
-            'title': ungettext(
-                singular='Attach tags to %(count)d document',
-                plural='Attach tags to %(count)d documents',
-                number=queryset.count()
-            ) % {
-                'count': queryset.count(),
-            }
         }
 
-        if queryset.count() == 1:
-            result.update(
+        if self.object_list.count() == 1:
+            context.update(
                 {
-                    'object': queryset.first(),
-                    'title': _('Attach tags to document: %s') % queryset.first()
+                    'object': self.object_list.first(),
                 }
             )
 
-        return result
+        return context
 
     def get_form_extra_kwargs(self):
-        queryset = self.object_list
-        result = {
+        kwargs = {
             'help_text': _('Tags to be attached.'),
             'permission': permission_tag_attach,
             'queryset': Tag.objects.all(),
             'user': self.request.user
         }
 
-        if queryset.count() == 1:
-            result.update(
+        if self.object_list.count() == 1:
+            kwargs.update(
                 {
                     'queryset': Tag.objects.exclude(
-                        pk__in=queryset.first().tags.all()
+                        pk__in=self.object_list.first().tags.all()
                     )
                 }
             )
 
-        return result
+        return kwargs
 
     def get_post_action_redirect(self):
-        queryset = self.object_list
-        if queryset.count() == 1:
+        if self.object_list.count() == 1:
             return reverse(
                 viewname='tags:document_tag_list', kwargs={
-                    'document_id': queryset.first().pk
+                    'document_id': self.object_list.first().pk
                 }
             )
         else:
-            return super(TagAttachActionView, self).get_post_action_redirect()
+            return super().get_post_action_redirect()
 
     def object_action(self, form, instance):
-        attached_tags = instance.get_tags(
-            permission=permission_tag_attach, user=self.request.user
-        )
-
         for tag in form.cleaned_data['tags']:
             AccessControlList.objects.check_access(
                 obj=tag, permissions=(permission_tag_attach,),
                 user=self.request.user
             )
 
-            if tag in attached_tags:
-                messages.warning(
-                    message=_(
-                        'Document "%(document)s" is already tagged as '
-                        '"%(tag)s"'
-                    ) % {
-                        'document': instance, 'tag': tag
-                    }, request=self.request
-                )
-            else:
-                tag.attach_to(document=instance, user=self.request.user)
-                messages.success(
-                    message=_(
-                        'Tag "%(tag)s" attached successfully to document '
-                        '"%(document)s".'
-                    ) % {
-                        'document': instance, 'tag': tag
-                    }, request=self.request
-                )
+            tag._event_actor = self.request.user
+            tag.attach_to(document=instance)
 
 
 class TagCreateView(SingleObjectCreateView):
@@ -132,57 +106,42 @@ class TagCreateView(SingleObjectCreateView):
     post_action_redirect = reverse_lazy(viewname='tags:tag_list')
     view_permission = permission_tag_create
 
-    def get_save_extra_data(self):
-        return {'_user': self.request.user}
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
 
 
 class TagDeleteActionView(MultipleObjectConfirmActionView):
+    error_message = _('Error deleting tag "%(instance)s"; %(exception)s')
     model = Tag
     object_permission = permission_tag_delete
     pk_url_kwarg = 'tag_id'
     post_action_redirect = reverse_lazy(viewname='tags:tag_list')
-    success_message = _('Tag delete request performed on %(count)d tag')
-    success_message_plural = _(
-        'Tag delete request performed on %(count)d tags'
-    )
+    success_message_single = _('Tag "%(object)s" deleted successfully.')
+    success_message_singular = _('%(count)d tag deleted successfully.')
+    success_message_plural = _('%(count)d tags deleted successfully.')
+    title_single = _('Delete tag: %(object)s.')
+    title_singular = _('Delete the %(count)d selected tag.')
+    title_plural = _('Delete the %(count)d selected tags.')
 
     def get_extra_context(self):
-        queryset = self.object_list
-
-        result = {
+        context = {
             'delete_view': True,
             'message': _('Will be removed from all documents.'),
-            'title': ungettext(
-                singular='Delete the selected tag?',
-                plural='Delete the selected tags?',
-                number=queryset.count()
-            )
         }
 
-        if queryset.count() == 1:
-            result.update(
+        if self.object_list.count() == 1:
+            context.update(
                 {
-                    'object': queryset.first(),
-                    'title': _('Delete tag: %s?') % queryset.first()
+                    'object': self.object_list.first(),
                 }
             )
 
-        return result
+        return context
 
     def object_action(self, instance, form=None):
-        try:
-            instance.delete()
-            messages.success(
-                message=_(
-                    'Tag "%s" deleted successfully.'
-                ) % instance, request=self.request
-            )
-        except Exception as exception:
-            messages.error(
-                message=_('Error deleting tag "%(tag)s": %(error)s') % {
-                    'tag': instance, 'error': exception
-                }, request=self.request
-            )
+        instance.delete()
 
 
 class TagEditView(SingleObjectEditView):
@@ -198,12 +157,15 @@ class TagEditView(SingleObjectEditView):
             'title': _('Edit tag: %s') % self.object,
         }
 
-    def get_save_extra_data(self):
-        return {'_user': self.request.user}
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
 
 
 class TagListView(SingleObjectListView):
     object_permission = permission_tag_view
+    tag_model = Tag
 
     def get_extra_context(self):
         return {
@@ -222,23 +184,27 @@ class TagListView(SingleObjectListView):
         }
 
     def get_source_queryset(self):
-        queryset = ModelQueryFields.get(model=Tag).get_queryset()
+        queryset = ModelQueryFields.get(model=self.tag_model).get_queryset()
         return queryset.filter(pk__in=self.get_tag_queryset())
 
     def get_tag_queryset(self):
         return Tag.objects.all()
 
 
-class TagDocumentListView(ExternalObjectMixin, DocumentListView):
+class TagDocumentListView(ExternalObjectViewMixin, DocumentListView):
     external_object_class = Tag
     external_object_permission = permission_tag_view
     external_object_pk_url_kwarg = 'tag_id'
 
     def get_document_queryset(self):
-        return self.get_tag().get_documents(user=self.request.user).all()
+        return Document.valid.filter(
+            pk__in=self.get_tag().get_documents(
+                permission=permission_tag_view, user=self.request.user
+            ).values('pk')
+        )
 
     def get_extra_context(self):
-        context = super(TagDocumentListView, self).get_extra_context()
+        context = super().get_extra_context()
         context.update(
             {
                 'object': self.get_tag(),
@@ -251,13 +217,14 @@ class TagDocumentListView(ExternalObjectMixin, DocumentListView):
         return self.external_object
 
 
-class DocumentTagListView(ExternalObjectMixin, TagListView):
-    external_object_class = Document
+class DocumentTagListView(ExternalObjectViewMixin, TagListView):
     external_object_permission = permission_tag_view
     external_object_pk_url_kwarg = 'document_id'
+    external_object_queryset = Document.valid
+    tag_model = DocumentTag
 
     def get_extra_context(self):
-        context = super(DocumentTagListView, self).get_extra_context()
+        context = super().get_extra_context()
         context.update(
             {
                 'hide_link': True,
@@ -283,94 +250,70 @@ class DocumentTagListView(ExternalObjectMixin, TagListView):
 
 class TagRemoveActionView(MultipleObjectFormActionView):
     form_class = TagMultipleSelectionForm
-    model = Document
     object_permission = permission_tag_remove
     pk_url_kwarg = 'document_id'
-    success_message = _('Tag remove request performed on %(count)d document')
-    success_message_plural = _(
-        'Tag remove request performed on %(count)d documents'
+    source_queryset = Document.valid
+    success_message_single = _(
+        'Tags removed from document "%(object)s" successfully.'
     )
+    success_message_singular = _(
+        'Tags removed from %(count)d document successfully.'
+    )
+    success_message_plural = _(
+        'Tags removed from %(count)d documents successfully.'
+    )
+    title_single = _('Remove tags from document: %(object)s')
+    title_singular = _('Remove tags from %(count)d document.')
+    title_plural = _('Remove tags from %(count)d documents.')
 
     def get_extra_context(self):
-        queryset = self.object_list
-
-        result = {
-            'submit_icon_class': icon_document_tag_remove_submit,
+        context = {
+            'submit_icon': icon_document_tag_remove_submit,
             'submit_label': _('Remove'),
-            'title': ungettext(
-                singular='Remove tags from %(count)d document',
-                plural='Remove tags from %(count)d documents',
-                number=queryset.count()
-            ) % {
-                'count': queryset.count(),
-            }
         }
 
-        if queryset.count() == 1:
-            result.update(
+        if self.object_list.count() == 1:
+            context.update(
                 {
-                    'object': queryset.first(),
-                    'title': _('Remove tags from document: %s') % queryset.first()
+                    'object': self.object_list.first(),
                 }
             )
 
-        return result
+        return context
 
     def get_form_extra_kwargs(self):
-        queryset = self.object_list
-        result = {
+        kwargs = {
             'help_text': _('Tags to be removed.'),
             'permission': permission_tag_remove,
             'queryset': Tag.objects.all(),
             'user': self.request.user
         }
 
-        if queryset.count() == 1:
-            result.update(
+        if self.object_list.count() == 1:
+            kwargs.update(
                 {
-                    'queryset': queryset.first().tags.all()
+                    'queryset': self.object_list.first().tags.all()
                 }
             )
 
-        return result
+        return kwargs
 
     def get_post_action_redirect(self):
-        queryset = self.object_list
-        if queryset.count() == 1:
+        if self.object_list.count() == 1:
             return reverse(
                 viewname='tags:document_tag_list', kwargs={
-                    'document_id': queryset.first().pk
+                    'document_id': self.object_list.first().pk
                 }
             )
         else:
-            return super(TagRemoveActionView, self).get_post_action_redirect()
+            return super().get_post_action_redirect()
 
     def object_action(self, form, instance):
-        attached_tags = instance.get_tags(
-            permission=permission_tag_remove, user=self.request.user
-        )
-
         for tag in form.cleaned_data['tags']:
             AccessControlList.objects.check_access(
                 obj=tag, permissions=(permission_tag_remove,),
                 user=self.request.user
             )
 
-            if tag not in attached_tags:
-                messages.warning(
-                    message=_(
-                        'Document "%(document)s" wasn\'t tagged as "%(tag)s'
-                    ) % {
-                        'document': instance, 'tag': tag
-                    }, request=self.request
-                )
-            else:
-                tag.remove_from(document=instance, user=self.request.user)
-                messages.success(
-                    message=_(
-                        'Tag "%(tag)s" removed successfully from document '
-                        '"%(document)s".'
-                    ) % {
-                        'document': instance, 'tag': tag
-                    }, request=self.request
-                )
+            tag._event_actor = self.request.user
+            tag.remove_from(document=instance)
