@@ -1,17 +1,17 @@
-from django.contrib.auth import get_user_model
 from django.contrib.auth.models import Group
-from django.shortcuts import get_object_or_404
 
-from mayan.apps.acls.models import AccessControlList
 from mayan.apps.rest_api import generics
+from mayan.apps.rest_api.api_view_mixins import ExternalObjectAPIViewMixin
 
 from .permissions import (
     permission_group_create, permission_group_delete, permission_group_edit,
     permission_group_view, permission_user_create, permission_user_delete,
     permission_user_edit, permission_user_view
 )
+from .querysets import get_user_queryset
 from .serializers import (
-    GroupSerializer, UserSerializer, UserGroupListSerializer
+    GroupSerializer, GroupUserAddSerializer, GroupUserRemoveSerializer,
+    UserSerializer
 )
 
 
@@ -28,24 +28,14 @@ class APICurrentUserView(generics.RetrieveUpdateDestroyAPIView):
         return self.request.user
 
 
-class APIGroupListView(generics.ListCreateAPIView):
-    """
-    get: Returns a list of all the groups.
-    post: Create a new group.
-    """
-    mayan_object_permissions = {'GET': (permission_group_view,)}
-    mayan_view_permissions = {'POST': (permission_group_create,)}
-    queryset = Group.objects.order_by('id')
-    serializer_class = GroupSerializer
-
-
-class APIGroupView(generics.RetrieveUpdateDestroyAPIView):
+class APIGroupDetailView(generics.RetrieveUpdateDestroyAPIView):
     """
     delete: Delete the selected group.
     get: Return the details of the selected group.
     patch: Partially edit the selected group.
     put: Edit the selected group.
     """
+    lookup_url_kwarg = 'group_id'
     mayan_object_permissions = {
         'GET': (permission_group_view,),
         'PUT': (permission_group_edit,),
@@ -55,6 +45,86 @@ class APIGroupView(generics.RetrieveUpdateDestroyAPIView):
     queryset = Group.objects.order_by('id')
     serializer_class = GroupSerializer
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
+
+class APIGroupListView(generics.ListCreateAPIView):
+    """
+    get: Returns a list of all the groups.
+    post: Create a new group.
+    """
+    mayan_object_permissions = {'GET': (permission_group_view,)}
+    mayan_view_permissions = {'POST': (permission_group_create,)}
+    ordering_fields = ('name',)
+    queryset = Group.objects.order_by('id')
+    serializer_class = GroupSerializer
+
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
+
+class APIGroupUserAddView(generics.ObjectActionAPIView):
+    """
+    post: Add a user to a group.
+    """
+    lookup_url_kwarg = 'group_id'
+    mayan_object_permissions = {
+        'POST': (permission_group_edit,)
+    }
+    serializer_class = GroupUserAddSerializer
+    queryset = Group.objects.all()
+
+    def object_action(self, request, serializer):
+        self.object._event_actor = self.request.user
+
+        self.object.users_add(
+            queryset=get_user_queryset().filter(
+                pk=serializer.validated_data['user'].pk
+            )
+        )
+
+
+class APIGroupUserListView(
+    ExternalObjectAPIViewMixin, generics.ListAPIView
+):
+    """
+    Returns a list of all the users belonging to the group.
+    """
+    external_object_queryset = Group.objects.all()
+    external_object_pk_url_kwarg = 'group_id'
+    mayan_external_object_permissions = {'GET': (permission_group_view,)}
+    mayan_object_permissions = {'GET': (permission_user_view,)}
+    serializer_class = UserSerializer
+
+    def get_queryset(self):
+        return self.external_object.user_set.all()
+
+
+class APIGroupUserRemoveView(generics.ObjectActionAPIView):
+    """
+    post: Remove a user from a group.
+    """
+    lookup_url_kwarg = 'group_id'
+    mayan_object_permissions = {
+        'POST': (permission_group_edit,)
+    }
+    serializer_class = GroupUserRemoveSerializer
+    queryset = Group.objects.all()
+
+    def object_action(self, request, serializer):
+        self.object._event_actor = self.request.user
+
+        self.object.users_remove(
+            queryset=get_user_queryset().filter(
+                pk=serializer.validated_data['user'].pk
+            )
+        )
+
 
 class APIUserListView(generics.ListCreateAPIView):
     """
@@ -63,78 +133,49 @@ class APIUserListView(generics.ListCreateAPIView):
     """
     mayan_object_permissions = {'GET': (permission_user_view,)}
     mayan_view_permissions = {'POST': (permission_user_create,)}
-    queryset = get_user_model().objects.all()
+    ordering_fields = (
+        'email', 'first_name', 'last_name', 'has_usable_password',
+        'is_active', 'username'
+    )
+    queryset = get_user_queryset()
     serializer_class = UserSerializer
 
+    def get_instance_extra_data(self):
+        return {'_event_actor': self.request.user}
 
-class APIUserView(generics.RetrieveUpdateDestroyAPIView):
+
+class APIUserDetailView(generics.RetrieveUpdateDestroyAPIView):
     """
     delete: Delete the selected user.
     get: Return the details of the selected user.
     patch: Partially edit the selected user.
     put: Edit the selected user.
     """
+    lookup_url_kwarg = 'user_id'
     mayan_object_permissions = {
         'GET': (permission_user_view,),
         'PUT': (permission_user_edit,),
         'PATCH': (permission_user_edit,),
         'DELETE': (permission_user_delete,)
     }
-    queryset = get_user_model().objects.all()
+    queryset = get_user_queryset()
     serializer_class = UserSerializer
 
+    def get_instance_extra_data(self):
+        return {'_event_actor': self.request.user}
 
-class APIUserGroupList(generics.ListCreateAPIView):
+
+class APIUserGroupListView(
+    ExternalObjectAPIViewMixin, generics.ListAPIView
+):
     """
-    get: Returns a list of all the groups to which a user belongs.
-    post: Add a user to a list of groups.
+    Returns a list of all the groups to which the user belongings.
     """
-    def get_serializer(self, *args, **kwargs):
-        if not self.request:
-            return None
-
-        return super(APIUserGroupList, self).get_serializer(*args, **kwargs)
-
-    def get_serializer_class(self):
-        if self.request.method == 'GET':
-            return GroupSerializer
-        elif self.request.method == 'POST':
-            return UserGroupListSerializer
-
-    def get_serializer_context(self):
-        """
-        Extra context provided to the serializer class.
-        """
-        context = super(APIUserGroupList, self).get_serializer_context()
-        if self.kwargs:
-            context.update(
-                {
-                    'user': self.get_user(),
-                }
-            )
-
-        return context
+    external_object_queryset = get_user_queryset()
+    external_object_pk_url_kwarg = 'user_id'
+    mayan_external_object_permissions = {'GET': (permission_user_view,)}
+    mayan_object_permissions = {'GET': (permission_group_view,)}
+    serializer_class = GroupSerializer
 
     def get_queryset(self):
-        user = self.get_user()
-
-        return AccessControlList.objects.restrict_queryset(
-            permission=permission_group_view,
-            queryset=user.groups.order_by('id'), user=self.request.user
-        )
-
-    def get_user(self):
-        if self.request.method == 'GET':
-            permission = permission_user_view
-        else:
-            permission = permission_user_edit
-
-        user = get_object_or_404(klass=get_user_model(), pk=self.kwargs['pk'])
-
-        AccessControlList.objects.check_access(
-            obj=user, permissions=(permission,), user=self.request.user
-        )
-        return user
-
-    def perform_create(self, serializer):
-        serializer.save(user=self.get_user(), _user=self.request.user)
+        return self.external_object.groups.all()
