@@ -1,8 +1,9 @@
 from django.conf.urls import url
 
 from .api_views import (
-    APICurrentUserView, APIGroupListView, APIGroupView, APIUserGroupList,
-    APIUserListView, APIUserView
+    APICurrentUserView, APIGroupDetailView, APIGroupListView,
+    APIGroupUserAddView, APIGroupUserListView, APIGroupUserRemoveView,
+    APIUserDetailView, APIUserGroupListView, APIUserListView
 )
 from .views import (
     CurrentUserDetailsView, CurrentUserEditView, GroupCreateView,
@@ -84,12 +85,26 @@ urlpatterns.extend(urlpatterns_users)
 api_urls = [
     url(regex=r'^groups/$', view=APIGroupListView.as_view(), name='group-list'),
     url(
-        regex=r'^groups/(?P<pk>[0-9]+)/$', view=APIGroupView.as_view(),
+        regex=r'^groups/(?P<group_id>[0-9]+)/$', view=APIGroupDetailView.as_view(),
         name='group-detail'
     ),
+
+    url(
+        regex=r'^groups/(?P<group_id>[0-9]+)/users/$',
+        name='group-user-list',
+        view=APIGroupUserListView.as_view()
+    ),
+    url(
+        regex=r'^groups/(?P<group_id>[0-9]+)/users/add/$',
+        name='group-user-add', view=APIGroupUserAddView.as_view()
+    ),
+    url(
+        regex=r'^groups/(?P<group_id>[0-9]+)/users/remove/$',
+        name='group-user-remove', view=APIGroupUserRemoveView.as_view()
+    ),
     url(regex=r'^users/$', view=APIUserListView.as_view(), name='user-list'),
     url(
-        regex=r'^users/(?P<pk>[0-9]+)/$', view=APIUserView.as_view(),
+        regex=r'^users/(?P<user_id>[0-9]+)/$', view=APIUserDetailView.as_view(),
         name='user-detail'
     ),
     url(
@@ -97,7 +112,7 @@ api_urls = [
         name='user-current'
     ),
     url(
-        regex=r'^users/(?P<pk>[0-9]+)/groups/$',
-        view=APIUserGroupList.as_view(), name='users-group-list'
+        regex=r'^users/(?P<user_id>[0-9]+)/groups/$',
+        view=APIUserGroupListView.as_view(), name='user-group-list'
     ),
 ]
