@@ -14,9 +14,6 @@ from mayan.apps.documents.links.document_type_links import (
     link_document_type_list
 )
 from mayan.apps.events.classes import EventModelRegistry, ModelEventType
-from mayan.apps.events.links import (
-    link_events_for_object, link_object_event_types_user_subcriptions_list
-)
 from mayan.apps.navigation.classes import SourceColumn
 from mayan.apps.views.html_widgets import TwoStateWidget
 
@@ -42,7 +39,7 @@ class WebLinksApp(MayanAppConfig):
     verbose_name = _('Links')
 
     def ready(self):
-        super(WebLinksApp, self).ready()
+        super().ready()
 
         Document = apps.get_model(
             app_label='documents', model_name='Document'
@@ -110,9 +107,7 @@ class WebLinksApp(MayanAppConfig):
         )
         menu_list_facet.bind_links(
             links=(
-                link_acl_list, link_events_for_object,
-                link_web_link_document_types,
-                link_object_event_types_user_subcriptions_list,
+                link_acl_list, link_web_link_document_types
             ), sources=(WebLink,)
         )
         menu_list_facet.bind_links(
